// PIO compatible header file STC11-STC10.h 20210829.
// For use with all STC11xx STC10xx series.
// 适用于 STC11xx STC10xx 系列的芯片。

#ifndef STC11_STC10_H
#define STC11_STC10_H
#include <compiler.h>

//SFR DEFINITION | NOTE | POR RESET VALUE  |  DESCRIPTION

SFR(P0, 0x80);                  //1111,1111 Port 0
   SBIT(P00, 0x80, 0); //Port 0 Bit 0
   SBIT(P01, 0x80, 1); //Port 0 Bit 1
   SBIT(P02, 0x80, 2); //Port 0 Bit 2
   SBIT(P03, 0x80, 3); //Port 0 Bit 3
   SBIT(P04, 0x80, 4); //Port 0 Bit 4
   SBIT(P05, 0x80, 5); //Port 0 Bit 5
   SBIT(P06, 0x80, 6); //Port 0 Bit 6
   SBIT(P07, 0x80, 7); //Port 0 Bit 7
   SBIT(P0_0, 0x80, 0); //Port 0 Bit 0
   SBIT(P0_1, 0x80, 1); //Port 0 Bit 1
   SBIT(P0_2, 0x80, 2); //Port 0 Bit 2
   SBIT(P0_3, 0x80, 3); //Port 0 Bit 3
   SBIT(P0_4, 0x80, 4); //Port 0 Bit 4
   SBIT(P0_5, 0x80, 5); //Port 0 Bit 5
   SBIT(P0_6, 0x80, 6); //Port 0 Bit 6
   SBIT(P0_7, 0x80, 7); //Port 0 Bit 7

SFR(SP, 0x81);                  //0000,0111 Stack Pointer

SFR(DPTR, 0x82);                //0000,0000 Data Pointer
SFR(DPL,  0x82);                //0000,0000 Data Pointer Low

SFR(DPH, 0x83);                 //0000,0000 Data Pointer High

SFR(PCON, 0x87);                //0011,0000|0001,0000 Power Control
   #define IDL   0x01 //Idle
   #define PD    0x02 //Power Down
   #define STOP  0x02 //Stop
   #define GF0   0x04 //General Flag 0
   #define GF1   0x08 //General Flag 1
   #define POF   0x10 //Power On Flag
   #define LVDF  0x10 //Low Voltage Detect Flag
   #define SMOD0 0x40 //Serial Mode 0
   #define SMOD  0x80 //Serial Mode

SFR(TCON, 0x88);                //0000,0000 Timer Control
   SBIT(IT0, 0x88, 0); //Interrupt 0 Type
   SBIT(IE0, 0x88, 1); //Interrupt 0 Edge
   SBIT(IT1, 0x88, 2); //Interrupt 1 Type
   SBIT(IE1, 0x88, 3); //Interrupt 1 Edge
   SBIT(TR0, 0x88, 4); //Timer 0 Run
   SBIT(TF0, 0x88, 5); //Timer 0 Flag
   SBIT(TR1, 0x88, 6); //Timer 1 Run
   SBIT(TF1, 0x88, 7); //Timer 1 Flag

SFR(TMOD, 0x89);                //0000,0000 Timer Mode
   #define T0_M0   0x01 //Timer 0 Mode 0
   #define T0_M1   0x02 //Timer 0 Mode 1
   #define T0_M    0x03 //Timer 0 Mode
   #define T0_CT   0x04 //Timer 0 Counter Timer
   #define T0_GATE 0x08 //Timer 0 Gate
   #define T1_M0   0x10 //Timer 1 Mode 0
   #define T1_M1   0x20 //Timer 1 Mode 1
   #define T1_M    0x30 //Timer 1 Mode
   #define T1_CT   0x40 //Timer 1 Counter Timer
   #define T1_GATE 0x80 //Timer 1 Gate
   #define M00   0x01 //Mode 0 Timer 0
   #define M10   0x02 //Mode 1 Timer 0
   #define M0    0x03 //Timer 0 Mode
   #define CT0   0x04 //Counter Timer 0
   #define GATE0 0x08 //Gate 0
   #define M01   0x10 //Mode 1 Timer 1
   #define M11   0x20 //Mode 1 Timer 1
   #define M1    0x30 //Timer 1 Mode
   #define CT1   0x40 //Counter Timer 1
   #define GATE1 0x80 //Gate 1

SFR(TL0, 0x8A);                 //0000,0000 Timer 0 Low

SFR(TL1, 0x8B);                 //0000,0000 Timer 1 Low

SFR(TH0, 0x8C);                 //0000,0000 Timer 0 High

SFR(TH1, 0x8D);                 //000x,0000 Timer 1 High

SFR(AUXR, 0x8E);                //0000,0000|0000,x000 Auxiliary Register
   #define S1BRS     0x01 //Serial 1 Baud Rate Select
   #define XRAM    0x02 //External RAM (what were they thinking!)
   #define EXTRAM    0x02 //External RAM
   #define BRTx12    0x04 //Baud Rate Times 12
   #define BRTR      0x10 //Baud Rate Timer Run
   #define UART_M0x6 0x20 //Universal Asynchronous Receiver Transmitter Baud Rate Mode 0 Times 6
   #define T1x12     0x40 //Timer 1 Times 12
   #define T0x12     0x80 //Timer 0 Times 12

SFR(WAKE_CLKO, 0x8F);           //0000,0000|x000,x000 Wakeup Clock Output
   #define T0CLKO     0x01 //Timer 0 Clock Overflow Output
   #define T1CLKO     0x02 //Timer 1 Clock Overflow Output
   #define BRTCLKO    0x04 //Baud Rate Timer Clock Overflow
   #define T0_PIN_IE  0x10 //Timer 0 Pin Interrupt Enable
   #define T1_PIN_IE  0x20 //Timer 1 Pin Interrupt Enable
   #define RXD_PIN_IE 0x40 //RXD Pin Interrupt Enable

// b6 - RXD_PIN_IE : 当 P3.0(RXD) 下降沿置位 RI 时可唤醒 powerdown(必须打开相应中断)。
// b5 - T1_PIN_IE : 当 T1 脚下降沿置位 T1 中断标志时可唤醒 powerdown(必须打开相应中断)。
// b4 - T0_PIN_IE : 当 T0 脚下降沿置位 T0 中断标志时可唤醒 powerdown(必须打开相应中断)。
// b2 - 
// b1 - T1CLKO : 允许 T1CKO(P3.5) 脚输出 T1 溢出脉冲，Fck1, 1/2 T1 溢出率
// b0 - T0CLKO : 允许 T0CKO(P3.4) 脚输出 T0 溢出脉冲，Fck0, 1/2 T1 溢出率

// b6 - RXD_PIN_IE: When the P3.0 (RXD) falling edge, PowerDown can be woken up (the corresponding interrupt must be opened).
// b5 - T1_PIN_IE: Wake PowerDown when the T1 pin falls along the T1 interrupt flag (must open the corresponding interrupt).
// b4 - T0_PIN_IE: Wake up PowerDown when the T0 foot falls along the T0 interrupt flag (must open the corresponding interrupt).
// b2 - BRTCLKO : Allow P1.0 foot output clock of Baud-Rate Timer (BRT). The clock rate is BRT overflow rate divided by 2.
// b1 - T1CLKO: Allow T1CKO (P3.5) foot output T1 overflow pulse, FCK1, 1/2 T1 overflow rate
// b0 - T0CLKO: Allow T0CKO (P3.4) foot output T0 overflow pulse, FCK0, 1/2 T1 overflow rate

SFR(P1, 0x90);                  //1111,1111 Port 1
   SBIT(CLKOUT2, 0x90, 0); //Clock Out 2
   SBIT(RXD_P1,  0x90, 6); //Receive Data
   SBIT(TXD_P1,  0x90, 7); //Transmit Data
   SBIT(P10, 0x90, 0); //Port 1 Bit 0
   SBIT(P11, 0x90, 1); //Port 1 Bit 1
   SBIT(P12, 0x90, 2); //Port 1 Bit 2
   SBIT(P13, 0x90, 3); //Port 1 Bit 3
   SBIT(P14, 0x90, 4); //Port 1 Bit 4
   SBIT(P15, 0x90, 5); //Port 1 Bit 5
   SBIT(P16, 0x90, 6); //Port 1 Bit 6
   SBIT(P17, 0x90, 7); //Port 1 Bit 7
   SBIT(P1_0, 0x90, 0); //Port 1 Bit 0
   SBIT(P1_1, 0x90, 1); //Port 1 Bit 1
   SBIT(P1_2, 0x90, 2); //Port 1 Bit 2
   SBIT(P1_3, 0x90, 3); //Port 1 Bit 3
   SBIT(P1_4, 0x90, 4); //Port 1 Bit 4
   SBIT(P1_5, 0x90, 5); //Port 1 Bit 5
   SBIT(P1_6, 0x90, 6); //Port 1 Bit 6
   SBIT(P1_7, 0x90, 7); //Port 1 Bit 7

SFR(P1M1, 0x91);                //0000,0000 Port 1 Mode 1
   #define P10M1 0x01 //Port 1 bit 0 Mode 1
   #define P11M1 0x02 //Port 1 bit 1 Mode 1
   #define P12M1 0x04 //Port 1 bit 2 Mode 1
   #define P13M1 0x08 //Port 1 bit 3 Mode 1
   #define P14M1 0x10 //Port 1 bit 4 Mode 1
   #define P15M1 0x20 //Port 1 bit 5 Mode 1
   #define P16M1 0x40 //Port 1 bit 6 Mode 1
   #define P17M1 0x80 //Port 1 bit 7 Mode 1

SFR(P1M0, 0x92);                //0000,0000 Port 1 Mode 0
   #define P10M0 0x01 //Port 1 bit 0 Mode 0
   #define P11M0 0x02 //Port 1 bit 1 Mode 0
   #define P12M0 0x04 //Port 1 bit 2 Mode 0
   #define P13M0 0x08 //Port 1 bit 3 Mode 0
   #define P14M0 0x10 //Port 1 bit 4 Mode 0
   #define P15M0 0x20 //Port 1 bit 5 Mode 0
   #define P16M0 0x40 //Port 1 bit 6 Mode 0
   #define P17M0 0x80 //Port 1 bit 7 Mode 0

SFR(P0M1, 0x93);                //0000,0000 Port 0 Mode 1
   #define P00M1 0x01 //Port 0 bit 0 Mode 1
   #define P01M1 0x02 //Port 0 bit 1 Mode 1
   #define P02M1 0x04 //Port 0 bit 2 Mode 1
   #define P03M1 0x08 //Port 0 bit 3 Mode 1
   #define P04M1 0x10 //Port 0 bit 4 Mode 1
   #define P05M1 0x20 //Port 0 bit 5 Mode 1
   #define P06M1 0x40 //Port 0 bit 6 Mode 1
   #define P07M1 0x80 //Port 0 bit 7 Mode 1

SFR(P0M0, 0x94);                //0000,0000 Port 0 Mode 0
   #define P00M0 0x01 //Port 0 bit 0 Mode 0
   #define P01M0 0x02 //Port 0 bit 1 Mode 0
   #define P02M0 0x04 //Port 0 bit 2 Mode 0
   #define P03M0 0x08 //Port 0 bit 3 Mode 0
   #define P04M0 0x10 //Port 0 bit 4 Mode 0
   #define P05M0 0x20 //Port 0 bit 5 Mode 0
   #define P06M0 0x40 //Port 0 bit 6 Mode 0
   #define P07M0 0x80 //Port 0 bit 7 Mode 0

SFR(P2M1, 0x95);                //0000,0000 Port 2 Mode 1
   #define P20M1 0x01 //Port 2 bit 0 Mode 1
   #define P21M1 0x02 //Port 2 bit 1 Mode 1
   #define P22M1 0x04 //Port 2 bit 2 Mode 1
   #define P23M1 0x08 //Port 2 bit 3 Mode 1
   #define P24M1 0x10 //Port 2 bit 4 Mode 1
   #define P25M1 0x20 //Port 2 bit 5 Mode 1
   #define P26M1 0x40 //Port 2 bit 6 Mode 1
   #define P27M1 0x80 //Port 2 bit 7 Mode 1

SFR(P2M0, 0x96);                //0000,0000 Port 2 Mode 0
   #define P20M0 0x01 //Port 2 bit 0 Mode 0
   #define P21M0 0x02 //Port 2 bit 1 Mode 0
   #define P22M0 0x04 //Port 2 bit 2 Mode 0
   #define P23M0 0x08 //Port 2 bit 3 Mode 0
   #define P24M0 0x10 //Port 2 bit 4 Mode 0
   #define P25M0 0x20 //Port 2 bit 5 Mode 0
   #define P26M0 0x40 //Port 2 bit 6 Mode 0
   #define P27M0 0x80 //Port 2 bit 7 Mode 0

SFR(CLK_DIV, 0x97);             //xxxx,x000 Clock Divider
   #define CLKS0 0x01 //Clock Select 0
   #define CLKS1 0x02 //Clock Select 1
   #define CLKS2 0x04 //Clock Select 2
   #define CLKS  0x07 //Clock Select

SFR(SCON, 0x98);                //0000,0000 Serial Control
   SBIT(RI,  0x98, 0); //Receive Interrupt
   SBIT(TI,  0x98, 1); //Transmit Interrupt
   SBIT(RB8, 0x98, 2); //Receive Bit 8
   SBIT(TB8, 0x98, 3); //Transmit Bit 8
   SBIT(REN, 0x98, 4); //Receive Enable
   SBIT(SM2, 0x98, 5); //Serial Mode 2
   SBIT(SM1, 0x98, 6); //Serial Mode 1
   SBIT(SM0, 0x98, 7); //Serial Mode 0
   SBIT(FE,  0x98, 7); //Framing Error

SFR(SBUF, 0x99);                //xxxx,xxxx Serial Buffer

SFR(BRT, 0x9C);                 //0000,0000 Serial 2 Baud Rate Timer

SFR(P2, 0xA0);                  //1111,1111 Port 2
   SBIT(P20, 0xA0, 0); //Port 2 Bit 0
   SBIT(P21, 0xA0, 1); //Port 2 Bit 1
   SBIT(P22, 0xA0, 2); //Port 2 Bit 2
   SBIT(P23, 0xA0, 3); //Port 2 Bit 3
   SBIT(P24, 0xA0, 4); //Port 2 Bit 4
   SBIT(P25, 0xA0, 5); //Port 2 Bit 5
   SBIT(P26, 0xA0, 6); //Port 2 Bit 6
   SBIT(P27, 0xA0, 7); //Port 2 Bit 7
   SBIT(P2_0, 0xA0, 0); //Port 2 Bit 0
   SBIT(P2_1, 0xA0, 1); //Port 2 Bit 1
   SBIT(P2_2, 0xA0, 2); //Port 2 Bit 2
   SBIT(P2_3, 0xA0, 3); //Port 2 Bit 3
   SBIT(P2_4, 0xA0, 4); //Port 2 Bit 4
   SBIT(P2_5, 0xA0, 5); //Port 2 Bit 5
   SBIT(P2_6, 0xA0, 6); //Port 2 Bit 6
   SBIT(P2_7, 0xA0, 7); //Port 2 Bit 7

SFR(BUS_SPEED, 0xA1);           //xx10,x011 Bus Speed
   #define RWS0  0x01 //Read Write Stretch 0
   #define RWS1  0x02 //Read Write Stretch 1
   #define RWS2  0x03 //Read Write Stretch 2
   #define RWS   0x07 //Read Write Stretch
   #define ALES0 0x10 //ALE Stretch 0
   #define ALES1 0x20 //ALE Stretch 1
   #define ALES  0x30 //ALE Stretch

// ALES1 and ALES0:
// 00 : The P0 address setup time and hold time to ALE negative edge is one clock cycle.
// 01 : The P0 address setup time and hold time to ALE negative edge is two clock cycles.
// 10 : The P0 address setup time and hold time to ALE negative edge is three clock cycles (default).
// 11 : The P0 address setup time and hold time to ALE negative edge is four clock cycles.

// RWS2,RWS1,RWS0:
//   000 : The MOVX read/write pulse is 1 clock cycle.
//   001 : The MOVX read/write pulse is 2 clock cycles.
//   010 : The MOVX read/write pulse is 3 clock cycles.
//   011 : The MOVX read/write pulse is 4 clock cycles (default).
//   100 : The MOVX read/write pulse is 5 clock cycles.
//   101 : The MOVX read/write pulse is 6 clock cycles.
//   110 : The MOVX read/write pulse is 7 clock cycles.
//   111 : The MOVX read/write pulse is 8 clock cycles.

SFR(AUXR1, 0xA2);               //xxxx,0xx0 Auxiliary Register 1
   #define DPS     0x01 //Data Pointer Select
   #define GF2     0x08 //General Flag 2
   #define UART_P1 0x80 //Universal Asynchronous Transmitter Receiver Port 1

// UART_P1:
//     0, 缺省UART 在P3 口
//     1，UART 从P3 口切换到P1 口: TxD 从P3.1 切换到P1.7 口
//                                  RxD 从P3.0 切换到P1.6 口
// GF2: 通用标志位

// DPS: 0, 使用缺省数据指针DPTR0
//      1，使用另一个数据指针DPTR1

// UART_P1:
//     0, the default UART in P3
//     1, UART Switch from P3 to P1 port: TXD Switch from P3.1 to P1.7
//                                  RXD switches from P3.0 to P1.6
// GF2: Universal Sign

// DPS: 0, use default data pointer DPTR0
//      1, use another data pointer DPTR1

SFR(TEST_WDT, 0xA7);            //xxxx,xxxx Test Watchdog Timer (do not use)

SFR(IE, 0xA8);                  //0x00,0000 Interrupt Enable
   SBIT(EX0,  0xA8, 0); //Enable External 0
   SBIT(ET0,  0xA8, 1); //Enable Timer 0
   SBIT(EX1,  0xA8, 2); //Enable External 1
   SBIT(ET1,  0xA8, 3); //Enable Timer 1
   SBIT(ES,   0xA8, 4); //Enable Serial
   SBIT(ELVD, 0xA8, 6); //Enable Low Voltage Detect
   SBIT(EA,   0xA8, 7); //Enable All

SFR(SADDR, 0xA9);               //0000,0000 Slave Address

// SFR(WKTCL, 0xAA); //Datasheet Error?
// SFR(WKTCH, 0xAB); //Datasheet Error?

SFR(P3, 0xB0);                  //1111,1111 Port 3
   SBIT(RXD,     0xB0, 0); //Receive Data
   SBIT(TXD,     0xB0, 1); //Transmit Data
   SBIT(INT0,    0xB0, 2); //Interrupt 0
   SBIT(INT1,    0xB0, 3); //Interrupt 1
   SBIT(T0,      0xB0, 4); //Timer 0
   SBIT(CLKOUT0, 0xB0, 4); //Clock Out 0
   SBIT(T1,      0xB0, 5); //Timer 1
   SBIT(CLKOUT1, 0xB0, 5); //Clock Out 1
   SBIT(WR,      0xB0, 6); //Write
   SBIT(RD,      0xB0, 7); //Read
   SBIT(P30, 0xB0, 0); //Port 3 Bit 0
   SBIT(P31, 0xB0, 1); //Port 3 Bit 1
   SBIT(P32, 0xB0, 2); //Port 3 Bit 2
   SBIT(P33, 0xB0, 3); //Port 3 Bit 3
   SBIT(P34, 0xB0, 4); //Port 3 Bit 4
   SBIT(P35, 0xB0, 5); //Port 3 Bit 5
   SBIT(P37, 0xB0, 7); //Port 3 Bit 7
   SBIT(P3_0, 0xB0, 0); //Port 3 Bit 0
   SBIT(P3_1, 0xB0, 1); //Port 3 Bit 1
   SBIT(P3_2, 0xB0, 2); //Port 3 Bit 2
   SBIT(P3_3, 0xB0, 3); //Port 3 Bit 3
   SBIT(P3_4, 0xB0, 4); //Port 3 Bit 4
   SBIT(P3_5, 0xB0, 5); //Port 3 Bit 5
   SBIT(P3_7, 0xB0, 7); //Port 3 Bit 7

SFR(P3M1, 0xB1);                //0000,0000 Port 3 Mode 1
   #define P30M1 0x01 //Port 3 bit 0 Mode 1
   #define P31M1 0x02 //Port 3 bit 1 Mode 1
   #define P32M1 0x04 //Port 3 bit 2 Mode 1
   #define P33M1 0x08 //Port 3 bit 3 Mode 1
   #define P34M1 0x10 //Port 3 bit 4 Mode 1
   #define P35M1 0x20 //Port 3 bit 5 Mode 1
   #define P36M1 0x40 //Port 3 bit 6 Mode 1
   #define P37M1 0x80 //Port 3 bit 7 Mode 1

SFR(P3M0, 0xB2);                //0000,0000 Port 3 Mode 0
   #define P30M0 0x01 //Port 3 bit 0 Mode 0
   #define P31M0 0x02 //Port 3 bit 1 Mode 0
   #define P32M0 0x04 //Port 3 bit 2 Mode 0
   #define P33M0 0x08 //Port 3 bit 3 Mode 0
   #define P34M0 0x10 //Port 3 bit 4 Mode 0
   #define P35M0 0x20 //Port 3 bit 5 Mode 0
   #define P36M0 0x40 //Port 3 bit 6 Mode 0
   #define P37M0 0x80 //Port 3 bit 7 Mode 0

SFR(P4M1, 0xB3);                //0000,0000 Port 4 Mode 1
   #define P40M1 0x01 //Port 4 bit 0 Mode 1
   #define P41M1 0x02 //Port 4 bit 1 Mode 1
   #define P42M1 0x04 //Port 4 bit 2 Mode 1
   #define P43M1 0x08 //Port 4 bit 3 Mode 1
   #define P44M1 0x10 //Port 4 bit 4 Mode 1
   #define P45M1 0x20 //Port 4 bit 5 Mode 1
   #define P46M1 0x40 //Port 4 bit 6 Mode 1
   #define P47M1 0x80 //Port 4 bit 7 Mode 1

SFR(P4M0, 0xB4);                //0000,0000 Port 4 Mode 0
   #define P40M0 0x01 //Port 4 bit 0 Mode 0
   #define P41M0 0x02 //Port 4 bit 1 Mode 0
   #define P42M0 0x04 //Port 4 bit 2 Mode 0
   #define P43M0 0x08 //Port 4 bit 3 Mode 0
   #define P44M0 0x10 //Port 4 bit 4 Mode 0
   #define P45M0 0x20 //Port 4 bit 5 Mode 0
   #define P46M0 0x40 //Port 4 bit 6 Mode 0
   #define P47M0 0x80 //Port 4 bit 7 Mode 0

SFR(IP, 0xB8);                  //0000,0000|x0x0,0000 Interrupt Priority
   SBIT(PX0,  0xB8, 0); //Priority External 0
   SBIT(PT0,  0xB8, 1); //Priority Timer 0
   SBIT(PX1,  0xB8, 2); //Priority External 1
   SBIT(PT1,  0xB8, 3); //Priority Timer 1
   SBIT(PS,   0xB8, 4); //Priority Serial
   SBIT(PLVD, 0xB8, 6); //Priority Low Voltage Detect

SFR(SADEN, 0xB9);               //0000,0000 Slave Address Enable

SFR(P4SW, 0xBB);                //x000,xxxx Port 4 Switch
   #define NA_P44  0x10 //Not Applicable Port 4 bit 4 (PSEN not implemented)
   #define ALE_P45 0x20 //Address Latch Enable Port 4 bit 5
   #define NA_P46  0x40 //Not Applicable External Access (EA not implemented)

SFR(P4, 0xC0);                  //1111,1111 Port 4
   SBIT(NA,    0xC0, 4); //Not Applicable (PSEN not implemented)
   SBIT(ALE,   0xC0, 5); //Address Latch Enable
   SBIT(P46NA, 0xC0, 6); //Port 4 but 6 Not Applicable (EA not implemented)
   SBIT(RST,   0xC0, 7); //Reset
   SBIT(P40, 0xC0, 0); //Port 4 Bit 0
   SBIT(P41, 0xC0, 1); //Port 4 Bit 1
   SBIT(P42, 0xC0, 2); //Port 4 Bit 2
   SBIT(P43, 0xC0, 3); //Port 4 Bit 3
   SBIT(P44, 0xC0, 4); //Port 4 Bit 4
   SBIT(P45, 0xC0, 5); //Port 4 Bit 5
   SBIT(P46, 0xC0, 6); //Port 4 Bit 6
   SBIT(P47, 0xC0, 7); //Port 4 Bit 6
   SBIT(P4_0, 0xC0, 0); //Port 4 Bit 0
   SBIT(P4_1, 0xC0, 1); //Port 4 Bit 1
   SBIT(P4_2, 0xC0, 2); //Port 4 Bit 2
   SBIT(P4_3, 0xC0, 3); //Port 4 Bit 3
   SBIT(P4_4, 0xC0, 4); //Port 4 Bit 4
   SBIT(P4_5, 0xC0, 5); //Port 4 Bit 5
   SBIT(P4_6, 0xC0, 6); //Port 4 Bit 6
   SBIT(P4_7, 0xC0, 7); //Port 4 Bit 7

SFR(WDT_CONTR, 0xC1);           //xx00,0000 Watchdog Timer Control
   #define PS0      0x01 //Prescale 0
   #define PS1      0x02 //Prescale 1
   #define PS2      0x04 //Prescale 2
   #define IDLE_WDT 0x08 //Idle Watchdog Timer
   #define CLR_WDT  0x10 //Clear Watchdog Timer
   #define EN_WDT   0x20 //Enable Watchdog Timer
   #define WDT_FLAG 0x80 //Watchdog Timer Flag

SFR(IAP_DATA, 0xC2);            //1111,1111 In Application Programming Data
SFR(ISP_DATA, 0xC2);            //In System Programming Data

SFR(IAP_ADDRH, 0xC3);           //0000,0000 In Application Programming Address High
SFR(ISP_ADDRH, 0xC3);           //In System Programming Address High

SFR(IAP_ADDRL, 0xC4);           //0000,0000 In Application Programming Address Low
SFR(ISP_ADDRL, 0xC4);           //In System Programming Address Low

SFR(IAP_CMD, 0xC5);             //xxxx,x000|xxxx,xx00 In Application Programming Command
SFR(ISP_CMD, 0xC5);             //In System Programming Command
   #define MS0    0x01 //Mode Select 0
   #define MS1    0x02 //Mode Select 1
   #define IAPCMD 0x03 //In Application Programming Command
// Valid commands follow
#define IAP_IDL   0x00
#define IAP_READ  0x01
#define IAP_WRITE 0x02
#define IAP_ERASE 0x03
// End of valid commands

SFR(IAP_TRIG, 0xC6);            //xxxx,xxxx In Application Programming Trigger
SFR(ISP_TRIG, 0xC6);            //In System Programming Trigger

SFR(IAP_CONTR, 0xC7);           //0000,x000|0000,0000 In Application Programming Control
SFR(ISP_CONTR, 0xC7);           //In System Programming Control
   #define WT0      0x01 //Wait 0
   #define WT1      0x02 //Wait 1
   #define WT2      0x04 //Wait 2
   #define IAP_WT   0x07 //In Application Programming Wait
   #define CMD_FAIL 0x10 //Command Fail
   #define SWRST    0x20 //Software Reset Trigger
   #define SWBS     0x40 //Software Boot Selection
   #define IAPEN    0x80 //In Application Programming Enable

SFR(PSW, 0xD0);                 //0000,0000 Program status word
   SBIT(P,   0xD0, 0); //Parity
   SBIT(F1,  0xD0, 1); //Flag 1
   SBIT(OV,  0xD0, 2); //Overflow
   SBIT(RS0, 0xD0, 3); //Register Select 0
   SBIT(RS1, 0xD0, 4); //Register Select 1
   SBIT(F0,  0xD0, 5); //Flag 0
   SBIT(AC,  0xD0, 6); //Auxiliary Carry
   SBIT(CY,  0xD0, 7); //Carry

SFR(ACC, 0xE0);                 //0000,0000 Accumulator
   SBIT(ACC0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC7, 0xE0, 7); //Accumulator Bit 7
   SBIT(ACC_0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC_1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC_2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC_3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC_4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC_5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC_6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC_7, 0xE0, 7); //Accumulator Bit 7

SFR(B, 0xF0);                   //0000,0000 B
   SBIT(B0, 0xF0, 0); //B Bit 0
   SBIT(B1, 0xF0, 1); //B Bit 1
   SBIT(B2, 0xF0, 2); //B Bit 2
   SBIT(B3, 0xF0, 3); //B Bit 3
   SBIT(B4, 0xF0, 4); //B Bit 4
   SBIT(B5, 0xF0, 5); //B Bit 5
   SBIT(B6, 0xF0, 6); //B Bit 6
   SBIT(B7, 0xF0, 7); //B Bit 7
   SBIT(B_0, 0xF0, 0); //B Bit 0
   SBIT(B_1, 0xF0, 1); //B Bit 1
   SBIT(B_2, 0xF0, 2); //B Bit 2
   SBIT(B_3, 0xF0, 3); //B Bit 3
   SBIT(B_4, 0xF0, 4); //B Bit 4
   SBIT(B_5, 0xF0, 5); //B Bit 5
   SBIT(B_6, 0xF0, 6); //B Bit 6
   SBIT(B_7, 0xF0, 7); //B Bit 7

//Interrupt numbers: Address = ( Number * 8 ) + 3
//Vectors are named after their corresponding interrupt
//enable register bit, so that we don't have to make up
//names and can be consisten across different 8051 MCUs
   #define X0_VECTOR  0 // 0x0003 External Interrupt 0
   #define T0_VECTOR  1 // 0x000B Timer 0
   #define X1_VECTOR  2 // 0x0013 External Interrupt 1
   #define T1_VECTOR  3 // 0x001B Timer 1
   #define S_VECTOR   4 // 0x0023 Serial Port
   //       -         5 // 0x002B       -
   #define LVD_VECTOR 6 // 0x0033 Low Voltage Detect

#endif