// PIO compatible header file STC12x5A.h 20210829.
// For use with all STC12C5Axx STC12LE5Axx series.
// 适用于 STC12C5Axx STC12LE5Axx 系列的芯片。

#ifndef STC12x5A_H
#define STC12x5A_H
#include <compiler.h>

//SFR DEFINITION | NOTE | POR RESET VALUE  |  DESCRIPTION

SFR(P0, 0x80);                  //1111,1111 Port 0
   SBIT(P00, 0x80, 0); //Port 0 Bit 0
   SBIT(P01, 0x80, 1); //Port 0 Bit 1
   SBIT(P02, 0x80, 2); //Port 0 Bit 2
   SBIT(P03, 0x80, 3); //Port 0 Bit 3
   SBIT(P04, 0x80, 4); //Port 0 Bit 4
   SBIT(P05, 0x80, 5); //Port 0 Bit 5
   SBIT(P06, 0x80, 6); //Port 0 Bit 6
   SBIT(P07, 0x80, 7); //Port 0 Bit 7
   SBIT(P0_0, 0x80, 0); //Port 0 Bit 0
   SBIT(P0_1, 0x80, 1); //Port 0 Bit 1
   SBIT(P0_2, 0x80, 2); //Port 0 Bit 2
   SBIT(P0_3, 0x80, 3); //Port 0 Bit 3
   SBIT(P0_4, 0x80, 4); //Port 0 Bit 4
   SBIT(P0_5, 0x80, 5); //Port 0 Bit 5
   SBIT(P0_6, 0x80, 6); //Port 0 Bit 6
   SBIT(P0_7, 0x80, 7); //Port 0 Bit 7

SFR(SP, 0x81);                  //0000,0111 Stack Pointer

SFR(DPTR, 0x82);                //0000,0000 Data Pointer
SFR(DPL,  0x82);                //0000,0000 Data Pointer Low

SFR(DPH, 0x83);                 //0000,0000 Data Pointer High

SFR(PCON, 0x87);                //0011,0000|0001,0000 Power Control
   #define IDL   0x01 //Idle
   #define PD    0x02 //Power Down
   #define STOP  0x02 //Stop
   #define GF0   0x04 //General Flag 0
   #define GF1   0x08 //General Flag 1
   #define POF   0x10 //Power On Flag
   #define LVDF  0x10 //Low Voltage Detect Flag
   #define SMOD0 0x40 //Serial Mode 0
   #define SMOD  0x80 //Serial Mode

SFR(TCON, 0x88);                //0000,0000 Timer Control
   SBIT(IT0, 0x88, 0); //Interrupt 0 Type
   SBIT(IE0, 0x88, 1); //Interrupt 0 Edge
   SBIT(IT1, 0x88, 2); //Interrupt 1 Type
   SBIT(IE1, 0x88, 3); //Interrupt 1 Edge
   SBIT(TR0, 0x88, 4); //Timer 0 Run
   SBIT(TF0, 0x88, 5); //Timer 0 Flag
   SBIT(TR1, 0x88, 6); //Timer 1 Run
   SBIT(TF1, 0x88, 7); //Timer 1 Flag

SFR(TMOD, 0x89);                //0000,0000 Timer Mode
   #define T0_M0   0x01 //Timer 0 Mode 0
   #define T0_M1   0x02 //Timer 0 Mode 1
   #define T0_M    0x03 //Timer 0 Mode
   #define T0_CT   0x04 //Timer 0 Counter Timer
   #define T0_GATE 0x08 //Timer 0 Gate
   #define T1_M0   0x10 //Timer 1 Mode 0
   #define T1_M1   0x20 //Timer 1 Mode 1
   #define T1_M    0x30 //Timer 1 Mode
   #define T1_CT   0x40 //Timer 1 Counter Timer
   #define T1_GATE 0x80 //Timer 1 Gate
   #define M00   0x01 //Mode 0 Timer 0
   #define M10   0x02 //Mode 1 Timer 0
   #define M0    0x03 //Timer 0 Mode
   #define CT0   0x04 //Counter Timer 0
   #define GATE0 0x08 //Gate 0
   #define M01   0x10 //Mode 1 Timer 1
   #define M11   0x20 //Mode 1 Timer 1
   #define M1    0x30 //Timer 1 Mode
   #define CT1   0x40 //Counter Timer 1
   #define GATE1 0x80 //Gate 1

SFR(TL0, 0x8A);                 //0000,0000 Timer 0 Low

SFR(TL1, 0x8B);                 //0000,0000 Timer 1 Low

SFR(TH0, 0x8C);                 //0000,0000 Timer 0 High

SFR(TH1, 0x8D);                 //0000,0000 Timer 1 High

SFR(AUXR, 0x8E);                //0000,0000 Auxiliary Register
   #define S1BRS     0x01 //Serial 1 Baud Rate Select
   #define EXTRAM    0x02 //External RAM
   #define BRTx12    0x04 //Baud Rate Times 12
   #define S2SMOD    0x08 //Serial 2 Serial baudrate Modify
   #define BRTR      0x10 //Baud Rate Timer Run
   #define UART_M0x6 0x20 //Universal Asynchronous Receiver Transmitter Baud Rate Mode 0 Times 6
   #define T1x12     0x40 //Timer 1 Times 12
   #define T0x12     0x80 //Timer 0 Times 12

SFR(WAKE_CLKO, 0x8F);           //0000,0000|0000,0x00 Wakeup Clock Output
   #define T0CLKO     0x01 //Timer 0 Clock Overflow Output
   #define T1CLKO     0x02 //Timer 1 Clock Overflow Output
   #define BRTCLKO    0x04 //Baud Rate Timer Clock Overflow
   #define LVD_WAKE   0x08 //Low Voltage Detect Wakeup
   #define T0_PIN_IE  0x10 //Timer 0 Pin Interrupt Enable
   #define T1_PIN_IE  0x20 //Timer 1 Pin Interrupt Enable
   #define RXD_PIN_IE 0x40 //RXD Pin Interrupt Enable
   #define PCAWAKEUP  0x80 //Programmable Counter Array Wakeup

// b7 - PCAWAKEUP : PCA 中断可唤醒 powerdown。
// b6 - RXD_PIN_IE : 当 P3.0(RXD) 下降沿置位 RI 时可唤醒 powerdown(必须打开相应中断)。
// b5 - T1_PIN_IE : 当 T1 脚下降沿置位 T1 中断标志时可唤醒 powerdown(必须打开相应中断)。
// b4 - T0_PIN_IE : 当 T0 脚下降沿置位 T0 中断标志时可唤醒 powerdown(必须打开相应中断)。
// b3 - LVD_WAKE : 当 CMPIN 脚低电平置位 LVD 中断标志时可唤醒 powerdown(必须打开相应中断)。
// b2 -
// b1 - T1CLKO : 允许 T1CKO(P3.5) 脚输出 T1 溢出脉冲，Fck1, 1/2 T1 溢出率
// b0 - T0CLKO : 允许 T0CKO(P3.4) 脚输出 T0 溢出脉冲，Fck0, 1/2 T1 溢出率

// b7 - PCAWAKEUP: PCA interrupts can wake up PowerDown.
// b6 - RXD_PIN_IE: When the P3.0 (RXD) falling edge, PowerDown can be woken up (the corresponding interrupt must be opened).
// b5 - T1_PIN_IE: Wake PowerDown when the T1 pin falls along the T1 interrupt flag (must open the corresponding interrupt).
// b4 - T0_PIN_IE: Wake up PowerDown when the T0 foot falls along the T0 interrupt flag (must open the corresponding interrupt).
// b3 - LVD_WAKE: Wake up PowerDown when the Cmpin foot is set to the LVD interrupt flag (must open the corresponding interrupt).
// b2 -
// b1 - T1CLKO: Allow T1CKO (P3.5) foot output T1 overflow pulse, FCK1, 1/2 T1 overflow rate
// b0 - T0CLKO: Allow T0CKO (P3.4) foot output T0 overflow pulse, FCK0, 1/2 T1 overflow rate

SFR(P1, 0x90);                  //1111,1111 Port 1
   SBIT(CLKOUT2, 0x90, 0); //Clock Out 2
   SBIT(RxD2,    0x90, 2); //Receive Data 2
   SBIT(ECI,     0x90, 2); //External Clock Input
   SBIT(TxD2,    0x90, 3); //Transmit Data 2
   SBIT(CCP0,    0x90, 3); //Compare Capture PWM 0
   SBIT(SS,      0x90, 4); //Slave Select
   SBIT(CCP1,    0x90, 4); //Compare Capture PWM 1
   SBIT(MOSI,    0x90, 5); //Master Out Slave In
   SBIT(MISO,    0x90, 6); //Master In Slave Out
   SBIT(SCLK,    0x90, 7); //Serial Clock
   SBIT(ACH0, 0x90, 0); //ADC Channel 0
   SBIT(ACH1, 0x90, 1); //ADC Channel 1
   SBIT(ACH2, 0x90, 2); //ADC Channel 2
   SBIT(ACH3, 0x90, 3); //ADC Channel 3
   SBIT(ACH4, 0x90, 4); //ADC Channel 4
   SBIT(ACH5, 0x90, 5); //ADC Channel 5
   SBIT(ACH6, 0x90, 6); //ADC Channel 6
   SBIT(ACH7, 0x90, 7); //ADC Channel 7
   SBIT(ADC0, 0x90, 0); //AtoD Channel 0
   SBIT(ADC1, 0x90, 1); //AtoD Channel 1
   SBIT(ADC2, 0x90, 2); //AtoD Channel 2
   SBIT(ADC3, 0x90, 3); //AtoD Channel 3
   SBIT(ADC4, 0x90, 4); //AtoD Channel 4
   SBIT(ADC5, 0x90, 5); //AtoD Channel 5
   SBIT(ADC6, 0x90, 6); //AtoD Channel 6
   SBIT(ADC7, 0x90, 7); //AtoD Channel 7
   SBIT(AIN0, 0x90, 0); //Analog Input 0
   SBIT(AIN1, 0x90, 1); //Analog Input 1
   SBIT(AIN2, 0x90, 2); //Analog Input 2
   SBIT(AIN3, 0x90, 3); //Analog Input 3
   SBIT(AIN4, 0x90, 4); //Analog Input 4
   SBIT(AIN5, 0x90, 5); //Analog Input 5
   SBIT(AIN6, 0x90, 6); //Analog Input 6
   SBIT(AIN7, 0x90, 7); //Analog Input 7
   SBIT(P10, 0x90, 0); //Port 1 Bit 0
   SBIT(P11, 0x90, 1); //Port 1 Bit 1
   SBIT(P12, 0x90, 2); //Port 1 Bit 2
   SBIT(P13, 0x90, 3); //Port 1 Bit 3
   SBIT(P14, 0x90, 4); //Port 1 Bit 4
   SBIT(P15, 0x90, 5); //Port 1 Bit 5
   SBIT(P16, 0x90, 6); //Port 1 Bit 6
   SBIT(P17, 0x90, 7); //Port 1 Bit 7
   SBIT(P1_0, 0x90, 0); //Port 1 Bit 0
   SBIT(P1_1, 0x90, 1); //Port 1 Bit 1
   SBIT(P1_2, 0x90, 2); //Port 1 Bit 2
   SBIT(P1_3, 0x90, 3); //Port 1 Bit 3
   SBIT(P1_4, 0x90, 4); //Port 1 Bit 4
   SBIT(P1_5, 0x90, 5); //Port 1 Bit 5
   SBIT(P1_6, 0x90, 6); //Port 1 Bit 6
   SBIT(P1_7, 0x90, 7); //Port 1 Bit 7

SFR(P1M1, 0x91);                //0000,0000 Port 1 Mode 1
   #define P10M1 0x01 //Port 1 bit 0 Mode 1
   #define P11M1 0x02 //Port 1 bit 1 Mode 1
   #define P12M1 0x04 //Port 1 bit 2 Mode 1
   #define P13M1 0x08 //Port 1 bit 3 Mode 1
   #define P14M1 0x10 //Port 1 bit 4 Mode 1
   #define P15M1 0x20 //Port 1 bit 5 Mode 1
   #define P16M1 0x40 //Port 1 bit 6 Mode 1
   #define P17M1 0x80 //Port 1 bit 7 Mode 1

SFR(P1M0, 0x92);                //0000,0000 Port 1 Mode 0
   #define P10M0 0x01 //Port 1 bit 0 Mode 0
   #define P11M0 0x02 //Port 1 bit 1 Mode 0
   #define P12M0 0x04 //Port 1 bit 2 Mode 0
   #define P13M0 0x08 //Port 1 bit 3 Mode 0
   #define P14M0 0x10 //Port 1 bit 4 Mode 0
   #define P15M0 0x20 //Port 1 bit 5 Mode 0
   #define P16M0 0x40 //Port 1 bit 6 Mode 0
   #define P17M0 0x80 //Port 1 bit 7 Mode 0

SFR(P0M1, 0x93);                //0000,0000 Port 0 Mode 1
   #define P00M1 0x01 //Port 0 bit 0 Mode 1
   #define P01M1 0x02 //Port 0 bit 1 Mode 1
   #define P02M1 0x04 //Port 0 bit 2 Mode 1
   #define P03M1 0x08 //Port 0 bit 3 Mode 1
   #define P04M1 0x10 //Port 0 bit 4 Mode 1
   #define P05M1 0x20 //Port 0 bit 5 Mode 1
   #define P06M1 0x40 //Port 0 bit 6 Mode 1
   #define P07M1 0x80 //Port 0 bit 7 Mode 1

SFR(P0M0, 0x94);                //0000,0000 Port 0 Mode 0
   #define P00M0 0x01 //Port 0 bit 0 Mode 0
   #define P01M0 0x02 //Port 0 bit 1 Mode 0
   #define P02M0 0x04 //Port 0 bit 2 Mode 0
   #define P03M0 0x08 //Port 0 bit 3 Mode 0
   #define P04M0 0x10 //Port 0 bit 4 Mode 0
   #define P05M0 0x20 //Port 0 bit 5 Mode 0
   #define P06M0 0x40 //Port 0 bit 6 Mode 0
   #define P07M0 0x80 //Port 0 bit 7 Mode 0

SFR(P2M1, 0x95);                //0000,0000 Port 2 Mode 1
   #define P20M1 0x01 //Port 2 bit 0 Mode 1
   #define P21M1 0x02 //Port 2 bit 1 Mode 1
   #define P22M1 0x04 //Port 2 bit 2 Mode 1
   #define P23M1 0x08 //Port 2 bit 3 Mode 1
   #define P24M1 0x10 //Port 2 bit 4 Mode 1
   #define P25M1 0x20 //Port 2 bit 5 Mode 1
   #define P26M1 0x40 //Port 2 bit 6 Mode 1
   #define P27M1 0x80 //Port 2 bit 7 Mode 1

SFR(P2M0, 0x96);                //0000,0000 Port 2 Mode 0
   #define P20M0 0x01 //Port 2 bit 0 Mode 0
   #define P21M0 0x02 //Port 2 bit 1 Mode 0
   #define P22M0 0x04 //Port 2 bit 2 Mode 0
   #define P23M0 0x08 //Port 2 bit 3 Mode 0
   #define P24M0 0x10 //Port 2 bit 4 Mode 0
   #define P25M0 0x20 //Port 2 bit 5 Mode 0
   #define P26M0 0x40 //Port 2 bit 6 Mode 0
   #define P27M0 0x80 //Port 2 bit 7 Mode 0

SFR(CLK_DIV, 0x97);             //xxxx,x000 Clock Divider
   #define CLKS0 0x01 //Clock Select 0
   #define CLKS1 0x02 //Clock Select 1
   #define CLKS2 0x04 //Clock Select 2
   #define CLKS  0x07 //Clock Select

SFR(SCON, 0x98);                //0000,0000 Serial Control
   SBIT(RI,  0x98, 0); //Receive Interrupt
   SBIT(TI,  0x98, 1); //Transmit Interrupt
   SBIT(RB8, 0x98, 2); //Receive Bit 8
   SBIT(TB8, 0x98, 3); //Transmit Bit 8
   SBIT(REN, 0x98, 4); //Receive Enable
   SBIT(SM2, 0x98, 5); //Serial Mode 2
   SBIT(SM1, 0x98, 6); //Serial Mode 1
   SBIT(SM0, 0x98, 7); //Serial Mode 0
   SBIT(FE,  0x98, 7); //Framing Error

SFR(SBUF, 0x99);                //xxxx,xxxx Serial Buffer

SFR(S2CON, 0x9A);               //0000,0000 Serial 2 Control
   #define S2RI  0x01 //Serial 2 Receive Interrupt
   #define S2TI  0x02 //Serial 2 Transmit Interrupt
   #define S2RB8 0x04 //Serial 2 Receive Bit 8
   #define S2TB8 0x08 //Serial 2 Transmit Bit 8
   #define S2REN 0x10 //Serial 2 Receive Enable
   #define S2SM2 0x20 //Serial 2 Serial Mode 2
   #define S2SM1 0x40 //Serial 2 Serial Mode 1
   #define S2SM0 0x80 //Serial 2 Serial Mode 0

SFR(S2BUF, 0x9B);               //xxxx,xxxx Serial 2 Buffer

SFR(BRT, 0x9C);                 //0000,0000 Serial 2 Baud Rate Timer

SFR(P1ASF, 0x9D);               //0000,0000 Port 1 Analog Special Function
   #define P10ASF 0x01 //Port 1 bit 0 Analdog Special Function
   #define P11ASF 0x02 //Port 1 bit 1 Analdog Special Function
   #define P12ASF 0x04 //Port 1 bit 2 Analdog Special Function
   #define P13ASF 0x08 //Port 1 bit 3 Analdog Special Function
   #define P14ASF 0x10 //Port 1 bit 4 Analdog Special Function
   #define P15ASF 0x20 //Port 1 bit 5 Analdog Special Function
   #define P16ASF 0x40 //Port 1 bit 6 Analdog Special Function
   #define P17ASF 0x80 //Port 1 bit 7 Analdog Special Function

SFR(P2, 0xA0);                  //1111,1111 Port 2
   SBIT(P20, 0xA0, 0); //Port 2 Bit 0
   SBIT(P21, 0xA0, 1); //Port 2 Bit 1
   SBIT(P22, 0xA0, 2); //Port 2 Bit 2
   SBIT(P23, 0xA0, 3); //Port 2 Bit 3
   SBIT(P24, 0xA0, 4); //Port 2 Bit 4
   SBIT(P25, 0xA0, 5); //Port 2 Bit 5
   SBIT(P26, 0xA0, 6); //Port 2 Bit 6
   SBIT(P27, 0xA0, 7); //Port 2 Bit 7
   SBIT(P2_0, 0xA0, 0); //Port 2 Bit 0
   SBIT(P2_1, 0xA0, 1); //Port 2 Bit 1
   SBIT(P2_2, 0xA0, 2); //Port 2 Bit 2
   SBIT(P2_3, 0xA0, 3); //Port 2 Bit 3
   SBIT(P2_4, 0xA0, 4); //Port 2 Bit 4
   SBIT(P2_5, 0xA0, 5); //Port 2 Bit 5
   SBIT(P2_6, 0xA0, 6); //Port 2 Bit 6
   SBIT(P2_7, 0xA0, 7); //Port 2 Bit 7

SFR(BUS_SPEED, 0xA1);           //xx10,x011 Bus Speed
   #define RWS0  0x01 //Read Write Stretch 0
   #define RWS1  0x02 //Read Write Stretch 1
   #define RWS2  0x03 //Read Write Stretch 2
   #define RWS   0x07 //Read Write Stretch
   #define ALES0 0x10 //ALE Stretch 0
   #define ALES1 0x20 //ALE Stretch 1
   #define ALES  0x30 //ALE Stretch

// ALES1 and ALES0:
// 00 : The P0 address setup time and hold time to ALE negative edge is one clock cycle.
// 01 : The P0 address setup time and hold time to ALE negative edge is two clock cycles.
// 10 : The P0 address setup time and hold time to ALE negative edge is three clock cycles (default).
// 11 : The P0 address setup time and hold time to ALE negative edge is four clock cycles.

// RWS2,RWS1,RWS0:
//   000 : The MOVX read/write pulse is 1 clock cycle.
//   001 : The MOVX read/write pulse is 2 clock cycles.
//   010 : The MOVX read/write pulse is 3 clock cycles.
//   011 : The MOVX read/write pulse is 4 clock cycles (default).
//   100 : The MOVX read/write pulse is 5 clock cycles.
//   101 : The MOVX read/write pulse is 6 clock cycles.
//   110 : The MOVX read/write pulse is 7 clock cycles.
//   111 : The MOVX read/write pulse is 8 clock cycles.

SFR(AUXR1, 0xA2);               //0000,0000|x000,00x0 Auxiliary Register 1
   #define DPS    0x01 //Data Pointer Select
   #define ADRJ   0x04 //Analog to Digital Result Juxtapose
   #define GF2    0x08 //General Flag 2
   #define S2_P4  0x10 //Serial Port 2 Port 4
   #define SPI_P4 0x20 //Serial Peripheral Interface Port 4
   #define PCA_P4 0x40 //Programmable Counter Array Port 4

// PCA_P4:
//     0, 缺省PCA 在P1 口
//     1，PCA/PWM 从P1 口切换到P4 口: ECI 从P1.2 切换到P4.1 口，
//                                    PCA0/PWM0 从P1.3 切换到P4.2 口
//                                    PCA1/PWM1 从P1.4 切换到P4.3 口
// SPI_P4:
//     0, 缺省SPI 在P1 口
//     1，SPI 从P1 口切换到P4 口: SPICLK 从P1.7 切换到P4.3 口
//                                MISO 从P1.6 切换到P4.2 口
//                                MOSI 从P1.5 切换到P4.1 口
//                                SS 从P1.4 切换到P4.0 口
// S2_P4:
//     0, 缺省UART2 在P1 口
//     1，UART2 从P1 口切换到P4 口: TxD2 从P1.3 切换到P4.3 口
//                                  RxD2 从P1.2 切换到P4.2 口
// GF2: 通用标志位

// ADRJ:
//     0, 10 位A/D 转换结果的高8 位放在ADC_RES 寄存器, 低2 位放在ADC_RESL 寄存器
//     1，10 位A/D 转换结果的最高2 位放在ADC_RES 寄存器的低2 位, 低8 位放在ADC_RESL 寄存器

// DPS: 0, 使用缺省数据指针DPTR0
//      1，使用另一个数据指针DPTR1

// PCA_P4:
//     0, default PCA in P1
//     1. PCA/PWM is switched from P1 to P4 port: ECI is switched from P1.2 to P4.1 port,
//                                    PCA0/PWM0 switches from P1.3 to P4.2
//                                    PCA1/PWM1 switches from P1.4 to P4.3
// SPI_P4:
//     0, default SPI in P1
//     1, SPI switches from P1 port to P4 port: SPICLK switches from P1.7 to P4.3
//                                MISO switches from P1.6 to P4.2
//                                MOSI switches from P1.5 to P4.1
//                                SS switches from P1.4 to P4.0
// S2_P4:
//     0, the default UART2 in P1
//     1, UART2 Switch from P1 to P4 port: TXD2 Switch from P1.3 to P4.3
//                                  RXD2 switches from P1.2 to P4.2
// GF2: Universal Sign

// Adrj:
//     0, 10-bit A/D conversion results high 8 bits placed on the ADC_RES register, low 2 bits in the ADC_RESL register
//     1,10-bit A/D conversion results are placed in the low 2 bits of the ADC_RES register, and the low 8 bits are placed in the ADC_RESL register.

// DPS: 0, use default data pointer DPTR0
//      1, use another data pointer DPTR1

SFR(TEST_WDT, 0xA7);            //xxxx,xxxx Test Watchdog Timer (do not use)

SFR(IE, 0xA8);                  //0000,0000|0x00,0000 Interrupt Enable
   SBIT(EX0,  0xA8, 0); //Enable External 0
   SBIT(ET0,  0xA8, 1); //Enable Timer 0
   SBIT(EX1,  0xA8, 2); //Enable External 1
   SBIT(ET1,  0xA8, 3); //Enable Timer 1
   SBIT(ES,   0xA8, 4); //Enable Serial
   SBIT(EADC, 0xA8, 5); //Enable Analog to Digital Converter
   SBIT(ELVD, 0xA8, 6); //Enable Low Voltage Detect
   SBIT(EA,   0xA8, 7); //Enable All

SFR(SADDR, 0xA9);               //0000,0000 Slave Address

SFR(IE2, 0xAF);                 //xxxx,xx00 Interrupt Enable 2
   #define ES2  0x01 //Enable Serial 2
   #define ESPI 0x02 //Enable Serial Peripheral Interface

SFR(P3, 0xB0);                  //1111,1111 Port 3
   SBIT(RXD,     0xB0, 0); //Receive Data
   SBIT(TXD,     0xB0, 1); //Transmit Data
   SBIT(INT0,    0xB0, 2); //Interrupt 0
   SBIT(INT1,    0xB0, 3); //Interrupt 1
   SBIT(T0,      0xB0, 4); //Timer 0
   SBIT(CLKOUT0, 0xB0, 4); //Clock Out 0
   SBIT(T1,      0xB0, 5); //Timer 1
   SBIT(CLKOUT1, 0xB0, 5); //Clock Out 1
   SBIT(WR,      0xB0, 6); //Write
   SBIT(RD,      0xB0, 7); //Read
   SBIT(P30, 0xB0, 0); //Port 3 Bit 0
   SBIT(P31, 0xB0, 1); //Port 3 Bit 1
   SBIT(P32, 0xB0, 2); //Port 3 Bit 2
   SBIT(P33, 0xB0, 3); //Port 3 Bit 3
   SBIT(P34, 0xB0, 4); //Port 3 Bit 4
   SBIT(P35, 0xB0, 5); //Port 3 Bit 5
   SBIT(P36, 0xB0, 6); //Port 3 Bit 6
   SBIT(P37, 0xB0, 7); //Port 3 Bit 7
   SBIT(P3_0, 0xB0, 0); //Port 3 Bit 0
   SBIT(P3_1, 0xB0, 1); //Port 3 Bit 1
   SBIT(P3_2, 0xB0, 2); //Port 3 Bit 2
   SBIT(P3_3, 0xB0, 3); //Port 3 Bit 3
   SBIT(P3_4, 0xB0, 4); //Port 3 Bit 4
   SBIT(P3_5, 0xB0, 5); //Port 3 Bit 5
   SBIT(P3_6, 0xB0, 6); //Port 3 Bit 6
   SBIT(P3_7, 0xB0, 7); //Port 3 Bit 7

SFR(P3M1, 0xB1);                //0000,0000 Port 3 Mode 1
   #define P30M1 0x01 //Port 3 bit 0 Mode 1
   #define P31M1 0x02 //Port 3 bit 1 Mode 1
   #define P32M1 0x04 //Port 3 bit 2 Mode 1
   #define P33M1 0x08 //Port 3 bit 3 Mode 1
   #define P34M1 0x10 //Port 3 bit 4 Mode 1
   #define P35M1 0x20 //Port 3 bit 5 Mode 1
   #define P36M1 0x40 //Port 3 bit 6 Mode 1
   #define P37M1 0x80 //Port 3 bit 7 Mode 1

SFR(P3M0, 0xB2);                //0000,0000 Port 3 Mode 0
   #define P30M0 0x01 //Port 3 bit 0 Mode 0
   #define P31M0 0x02 //Port 3 bit 1 Mode 0
   #define P32M0 0x04 //Port 3 bit 2 Mode 0
   #define P33M0 0x08 //Port 3 bit 3 Mode 0
   #define P34M0 0x10 //Port 3 bit 4 Mode 0
   #define P35M0 0x20 //Port 3 bit 5 Mode 0
   #define P36M0 0x40 //Port 3 bit 6 Mode 0
   #define P37M0 0x80 //Port 3 bit 7 Mode 0

SFR(P4M1, 0xB3);                //0000,0000 Port 4 Mode 1
   #define P40M1 0x01 //Port 4 bit 0 Mode 1
   #define P41M1 0x02 //Port 4 bit 1 Mode 1
   #define P42M1 0x04 //Port 4 bit 2 Mode 1
   #define P43M1 0x08 //Port 4 bit 3 Mode 1
   #define P44M1 0x10 //Port 4 bit 4 Mode 1
   #define P45M1 0x20 //Port 4 bit 5 Mode 1
   #define P46M1 0x40 //Port 4 bit 6 Mode 1
   #define P47M1 0x80 //Port 4 bit 7 Mode 1

SFR(P4M0, 0xB4);                //0000,0000 Port 4 Mode 0
   #define P40M0 0x01 //Port 4 bit 0 Mode 0
   #define P41M0 0x02 //Port 4 bit 1 Mode 0
   #define P42M0 0x04 //Port 4 bit 2 Mode 0
   #define P43M0 0x08 //Port 4 bit 3 Mode 0
   #define P44M0 0x10 //Port 4 bit 4 Mode 0
   #define P45M0 0x20 //Port 4 bit 5 Mode 0
   #define P46M0 0x40 //Port 4 bit 6 Mode 0
   #define P47M0 0x80 //Port 4 bit 7 Mode 0

SFR(IP2, 0xB5);                 //xxxx,xx00 Interrupt Priority 2
   #define PS2  0x01 //Priority Serial
   #define PSPI 0x02 //Priority Serial Peripheral Interface

SFR(IPH2, 0xB6);                //xxxx,xx00 Interrupt Priority High 2
   #define PS2H  0x01 //Priority Serial 2 High
   #define PSPIH 0x02 //Priority Serial Peripheral Interface High

SFR(IPH, 0xB7);                 //0000,0000 Interrupt Priority High
   #define PX0H  0x01 //Priority EXternal 0 High
   #define PT0H  0x02 //Priority Timer 0 High
   #define PX1H  0x04 //Priority External 1 High
   #define PT1H  0x08 //Priority Timer 1 High
   #define PSH   0x10 //Priority Serial High
   #define PADCH 0x20 //Priority Analog to Digital Converter High
   #define PLVDH 0x40 //Priority Low Voltage Detect High
   #define PPCAH 0x80 //Priority Programmable Counter Array High

SFR(IP, 0xB8);                  //0000,0000 Interrupt Priority
   SBIT(PX0,  0xB8, 0); //Priority External 0
   SBIT(PT0,  0xB8, 1); //Priority Timer 0
   SBIT(PX1,  0xB8, 2); //Priority External 1
   SBIT(PT1,  0xB8, 3); //Priority Timer 1
   SBIT(PS,   0xB8, 4); //Priority Serial
   SBIT(PADC, 0xB8, 5); //Priority Analog to Digital Converter
   SBIT(PLVD, 0xB8, 6); //Priority Low Voltage Detect
   SBIT(PPCA, 0xB8, 7); //Priority Programmable Counter Array

SFR(SADEN, 0xB9);               //0000,0000 Slave Address Enable

SFR(P4SW, 0xBB);                //x000,xxxx Port 4 Switch
   #define NA_P44  0x10 //Not Applicable Port 4 bit 4 (PSEN not implemented)
   #define ALE_P45 0x20 //Address Latch Enable Port 4 bit 5
   #define LVD_P46 0x40 //Low Voltage Detect Port 4 bit 6

SFR(ADC_CONTR, 0xBC);           //0000,0000 Analog to Digital Converter Control
   #define CHS0      0x01 //Channel Select 0
   #define CHS1      0x02 //Channel Select 1
   #define CHS2      0x04 //Channel Select 2
   #define ADC_CHS   0x0F //ADC Analog Channel Select
   #define ADC_START 0x08 //Analog to Digital Converter Start
   #define ADC_FLAG  0x10 //Analog to Digital Converter Flag
   #define SPEED0    0x20 //Speed 0
   #define SPEED1    0x40 //Speed 1
   #define ADC_POWER 0x40 //Analog to Digital Converter Power

SFR(ADC_RES, 0xBD);             //0000,0000 Analog to Digital Converter Result

SFR(ADC_RESL, 0xBE);            //0000,0000 Analog to Digital Converter Result Low

SFR(P4, 0xC0);                  //1111,1111 Port 4
   SBIT(SS_P4,   0xC0, 0); //Slave Select Port 4
   SBIT(ECI_P4,  0xC0, 1); //External Clock Input Port 4
   SBIT(MOSI_P4, 0xC0, 1); //Master Out Slave In Port 4
   SBIT(CCP0_P4, 0xC0, 2); //Compare Capture PWM 0 Port 4
   SBIT(MISO_P4, 0xC0, 2); //Master In Slave Out secondry
   SBIT(CCP1_P4, 0xC0, 3); //Compare Capture PWM 1 Port 4
   SBIT(SCLK_P4, 0xC0, 3); //Serial Clock Port 4
   SBIT(NA,      0xC0, 4); //Not Applicable (PSEN not implemented)
   SBIT(ALE,     0xC0, 5); //Address Latch Enable
   SBIT(EX_LVD,  0xC0, 6); //External Low Voltage Detect
   SBIT(RST2,    0xC0, 6); //Reset 2
   SBIT(RST,     0xC0, 7); //Reset
   SBIT(P40, 0xC0, 0); //Port 4 Bit 0
   SBIT(P41, 0xC0, 1); //Port 4 Bit 1
   SBIT(P42, 0xC0, 2); //Port 4 Bit 2
   SBIT(P43, 0xC0, 3); //Port 4 Bit 3
   SBIT(P44, 0xC0, 4); //Port 4 Bit 4
   SBIT(P45, 0xC0, 5); //Port 4 Bit 5
   SBIT(P46, 0xC0, 6); //Port 4 Bit 6
   SBIT(P4_0, 0xC0, 0); //Port 4 Bit 0
   SBIT(P4_1, 0xC0, 1); //Port 4 Bit 1
   SBIT(P4_2, 0xC0, 2); //Port 4 Bit 2
   SBIT(P4_3, 0xC0, 3); //Port 4 Bit 3
   SBIT(P4_4, 0xC0, 4); //Port 4 Bit 4
   SBIT(P4_5, 0xC0, 5); //Port 4 Bit 5
   SBIT(P4_6, 0xC0, 6); //Port 4 Bit 6

SFR(WDT_CONTR, 0xC1);           //0x00,0000|xx00,0000 Watchdog Timer Control
   #define WDTPS0   0x01 //Prescale 0
   #define WDTPS1   0x02 //Prescale 1
   #define WDTPS2   0x04 //Prescale 2
   #define WDTPS    0x07 //Prescale
   #define IDLE_WDT 0x08 //Idle Watchdog Timer
   #define CLR_WDT  0x10 //Clear Watchdog Timer
   #define EN_WDT   0x20 //Enable Watchdog Timer
   #define WDT_FLAG 0x80 //Watchdog Timer Flag

SFR(IAP_DATA, 0xC2);            //1111,1111 In Application Programming Data
SFR(ISP_DATA, 0xC2);            //In System Programming Data

SFR(IAP_ADDRH, 0xC3);           //0000,0000 In Application Programming Address High
SFR(ISP_ADDRH, 0xC3);           //In System Programming Address High

SFR(IAP_ADDRL, 0xC4);           //0000,0000 In Application Programming Address Low
SFR(ISP_ADDRL, 0xC4);           //In System Programming Address Low

SFR(IAP_CMD, 0xC5);             //xxxx,x000|xxxx,xx00 In Application Programming Command
SFR(ISP_CMD, 0xC5);             //In System Programming Command
   #define MS0    0x01 //Mode Select 0
   #define MS1    0x02 //Mode Select 1
   #define IAPCMD 0x03 //In Application Programming Command
// Valid commands follow
#define IAP_IDL   0x00
#define IAP_READ  0x01
#define IAP_WRITE 0x02
#define IAP_ERASE 0x03
// End of valid commands

SFR(IAP_TRIG, 0xC6);            //xxxx,xxxx In Application Programming Trigger
SFR(ISP_TRIG, 0xC6);            //In System Programming Trigger

SFR(IAP_CONTR, 0xC7);           //0000,x000 In Application Programming Control
SFR(ISP_CONTR, 0xC7);           //In System Programming Control
   #define WT0      0x01 //Wait 0
   #define WT1      0x02 //Wait 1
   #define WT2      0x04 //Wait 2
   #define IAP_WT   0x07 //In Application Programming Wait
   #define CMD_FAIL 0x10 //Command Fail
   #define SWRST    0x20 //Software Reset Trigger
   #define SWBS     0x40 //Software Boot Selection
   #define IAPEN    0x80 //In Application Programming Enable

SFR(P5, 0xC8);                  //xxxx,1111 Port 5
   SBIT(P50, 0xC8, 0); //Port 5 Bit 0
   SBIT(P51, 0xC8, 1); //Port 5 Bit 1
   SBIT(P52, 0xC8, 2); //Port 5 Bit 2
   SBIT(P53, 0xC8, 3); //Port 5 Bit 3
   SBIT(P5_0, 0xC8, 0); //Port 5 Bit 0
   SBIT(P5_1, 0xC8, 1); //Port 5 Bit 1
   SBIT(P5_2, 0xC8, 2); //Port 5 Bit 2
   SBIT(P5_3, 0xC8, 3); //Port 5 Bit 3

SFR(P5M1, 0xC9);                //xxxx,0000|0000,0000 Port 5 Mode 1
   #define P50M1 0x01 //Port 5 bit 0 Mode 1
   #define P51M1 0x02 //Port 5 bit 1 Mode 1
   #define P52M1 0x04 //Port 5 bit 2 Mode 1
   #define P53M1 0x08 //Port 5 bit 3 Mode 1

SFR(P5M0, 0xCA);                //xxxx,0000|0000,0000 Port 5 Mode 0
   #define P50M0 0x01 //Port 5 bit 0 Mode 0
   #define P51M0 0x02 //Port 5 bit 1 Mode 0
   #define P52M0 0x04 //Port 5 bit 2 Mode 0
   #define P53M0 0x08 //Port 5 bit 3 Mode 0

SFR(SPSTAT, 0xCD);              //00xx,xxxx Serial Peripheral Status Register
   #define WCOL 0x40 //Write Collision
   #define SPIF 0x80 //Serial Peripheral Interface Flag

SFR(SPCTL, 0xCE);               //0000,0100 Serial Peripheral Control
   #define SPR0 0x00 //Serial Peripheral Rate 0
   #define SPR1 0x01 //Serial Peripheral Rate 1
   #define SPR  0x03 //Serial Peripheral Rate
   #define CPHA 0x04 //Clock Phase
   #define CPOL 0x08 //Clock Polarity
   #define MSTR 0x10 //Master
   #define DORD 0x20 //Data Order
   #define SPEN 0x40 //Serial Peripheral Enable
   #define SSIG 0x80 //Slave Select Signal

SFR(SPDAT, 0xCF);               //0000,0000 Serial Peripheral Data

SFR(PSW, 0xD0);                 //0000,0000 Program status word
   SBIT(P,   0xD0, 0); //Parity
   SBIT(F1,  0xD0, 1); //Flag 1
   SBIT(OV,  0xD0, 2); //Overflow
   SBIT(RS0, 0xD0, 3); //Register Select 0
   SBIT(RS1, 0xD0, 4); //Register Select 1
   SBIT(F0,  0xD0, 5); //Flag 0
   SBIT(AC,  0xD0, 6); //Auxiliary Carry
   SBIT(CY,  0xD0, 7); //Carry

SFR(CCON, 0xD8);                //00xx,xx00 PCA Control
   SBIT(CCF0, 0xD8, 0); //Capture Compare Flag 0
   SBIT(CCF1, 0xD8, 1); //Capture Compare Flag 1
   SBIT(CR,   0xD8, 6); //PCA Run
   SBIT(CF,   0xD8, 7); //PCA Flag

// CF: PCA计数器溢出标志,由硬件或软件置位,必须由软件清0。
// CR: 1:允许 PCA 计数器计数, 必须由软件清0。
// CCF1: PCA 模块1 中断标志, 由硬件置位, 必须由软件清0。
// CCF0: PCA 模块0 中断标志, 由硬件置位, 必须由软件清0。

// CF: PCA counter overflow flag, is set by hardware or software, must be cleared by software.
// CR: 1: Allows the PCA counter count, must be cleared by software.
// CCF1: PCA module 1 interrupt flag, is set by hardware, must be cleared by software.
// CCF0: PCA module 0 interrupt flag, is set by hardware, must be cleared by software.

SFR(CMOD, 0xD9);                //0xxx,0000|00xx,0000 PCA Mode
   #define ECF  0x01 //Enable PCA Flag
   #define CPS0 0x02 //PCA Pulse Source 0
   #define CPS1 0x04 //PCA Pulse Source 1
   #define CPS2 0x08 //PCA Pulse Source 2
   #define CPS  0x0E //PCA Pulse Source
   #define CIDL 0x80 //PCA Idle

// CIDL: idle 状态时 PCA 计数器是否继续计数, 0: 继续计数, 1: 停止计数。

// CPS2: PCA 计数器脉冲源选择位 2。
// CPS1: PCA 计数器脉冲源选择位 1。
// CPS0: PCA 计数器脉冲源选择位 0。
//    CPS2   CPS1   CPS0
//     0      0      0    系统时钟频率 fosc/12。
//     0      0      1    系统时钟频率 fosc/2。
//     0      1      0    Timer0 溢出。
//     0      1      1    由 ECI/P3.4 脚输入的外部时钟，最大 fosc/2。
//     1      0      0    系统时钟频率，  Fosc/1
//     1      0      1    系统时钟频率/4，Fosc/4
//     1      1      0    系统时钟频率/6，Fosc/6
//     1      1      1    系统时钟频率/8，Fosc/8

// ECF: PCA计数器溢出中断允许位, 1--允许 CF(CCON.7) 产生中断。

// CIDL: The PCA counter continues counts when the IDLE state, 0: Continue count, 1: Stop count.

// CPS2: PCA Counter Pulse Source Select Bits 2.
// CPS1: PCA Counter pulse source selection bit 1.
// CPS0: PCA Counter pulse source selection bit 0.
//     CPS2 CPS1 CPS0
//      0 0 0 System clock frequency FOSC / 12.
//      0 0 1 System clock frequency FOSC / 2.
//      0 1 0 TIMER0 overflow.
//      0 1 1 The external clock input by ECI / P3.4 is the maximum fosc / 2.
//      1 0 0 System Clock Frequency, FOSC / 1
//      1 0 1 System Clock Frequency / 4, FOSC / 4
//      1 1 0 System Clock Frequency / 6, FOSC / 6
//      1 1 1 System Clock Frequency / 8, FOSC / 8

// ECF: The PCA counter overflow interrupt allowed bit, 1 - Allow CF (CCON.7) to generate an interrupt.

SFR(CCAPM0, 0xDA);              //x000,0000 Compare Capture PWM Mode 0
   #define ECCF0  0x01 //Enable PCA Capture Flag 0
   #define PWM0   0x02 //Pulse Width Modulator 0
   #define TOG0   0x04 //Toggle 0
   #define MAT0   0x08 //Match 0
   #define CAPN0  0x10 //Capture Negative-going 0
   #define CAPP0  0x20 //Capture Positive-going 0
   #define ECOM0  0x40 //Enable Comparator 0

SFR(CCAPM1, 0xDB);              //x000,0000 Compare Capture PWM Mode 1
   #define ECCF1  0x01 //Enable PCA Capture Flag 1
   #define PWM1   0x02 //Pulse Width Modulator 1
   #define TOG1   0x04 //Toggle 1
   #define MAT1   0x08 //Match 1
   #define CAPN1  0x10 //Capture Negative-going 1
   #define CAPP1  0x20 //Capture Positive-going 1
   #define ECOM1  0x40 //Enable Comparator 1

// ECOMn, 1:允许比较功能。
// CAPPn, 1:允许上升沿触发捕捉功能。
// CAPNn, 1:允许下降沿触发捕捉功能。
// MATn, 1:当匹配情况发生时, 允许 CCON 中的 CCFn 置位。
// TOGn, 1:当匹配情况发生时, CEXn 将翻转。
// PWMn, 1:将 CEXn 设置为 PWM 输出。
// ECCFn, 1:允许 CCON 中的 CCFn 触发中断。

// ECOMn  CAPPn  CAPNn  MATn  TOGn  PWMn  ECCFn
//   0      0      0     0     0     0     0   0x00   未启用任何功能。
//   x      1      0     0     0     0     x   0x21   16位CEXn上升沿触发捕捉功能。
//   x      0      1     0     0     0     x   0x11   16位CEXn下降沿触发捕捉功能。
//   x      1      1     0     0     0     x   0x31   16位CEXn边沿(上、下沿)触发捕捉功能。
//   1      0      0     1     0     0     x   0x49   16位软件定时器。
//   1      0      0     1     1     0     x   0x4d   16位高速脉冲输出。
//   1      0      0     0     0     1     0   0x42   8位 PWM。

// ECOMn  CAPPn  CAPNn  MATn  TOGn  PWMn  ECCFn
//   0      0      0     0     0     0     0   0x00   无此操作
//   1      0      0     0     0     1     0   0x42   普通8位PWM, 无中断
//   1      1      0     0     0     1     1   0x63   PWM输出由低变高可产生中断
//   1      0      1     0     0     1     1   0x53   PWM输出由高变低可产生中断
//   1      1      1     0     0     1     1   0x73   PWM输出由低变高或由高变低都可产生中断

// ECOMN, 1: Allow comparison functions.
// CAPPN, 1: Allows the rising edge to trigger capture functions.
// CAPNN, 1: Allows the falling edge to trigger capture function.
// MATN, 1: When the match occurs, the CCFN in CCON is allowed.
// TOGN, 1: When the match occurs, Cexn will flip.
// PWMN, 1: Set CexN to PWM output.
// ECCFN, 1: Allows CCFN trigger interrupt in CCON.

// ECOMN CAPPN CAPNN MATN TOGN PWMN ECCFN
//   0 0 0 0 0 0 0 0x00 No function is not enabled.
//   X 1 0 0 0 0 x 0x21 16-bit CEXN rising edge trigger capture function.
//   X 0 1 0 0 0 x 0x11 16-bit CEXN falling edge trigger capture function.
//   X 1 1 0 0 0 x 0x31 16-bit CEXN edge (upper, down) trigger capture function.
//   1 0 0 1 0 0 x 0x49 16-bit software timer.
//   1 0 0 1 0 x 0x4D 16-bit high speed pulse output.
//   1 0 0 0 0 1 0 0 x 42 8-bit PWM.

// ECOMN CAPPN CAPNN MATN TOGN PWMN ECCFN
//   0 0 0 0 0 0 0 0x00 Non-this
//   1 0 0 0 0 1 0 0x42 Ordinary 8-bit PWM, no interrupt
//   1 1 0 0 0 1 1 0x63 PWM output from low change can be interrupted
//   1 0 1 0 0 1 1 0 x53 PWM output from high change low can generate interrupt
//   1 1 1 0 0 1 1 0x73 PWM output can be interrupted by low change or low high change

SFR(ACC, 0xE0);                 //0000,0000 Accumulator
   SBIT(ACC0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC7, 0xE0, 7); //Accumulator Bit 7
   SBIT(ACC_0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC_1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC_2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC_3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC_4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC_5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC_6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC_7, 0xE0, 7); //Accumulator Bit 7

SFR(CL, 0xE9);                  //0000,0000 PCA Low

SFR(CCAP0L, 0xEA);              //0000,0000 PCA Capture 0 Low

SFR(CCAP1L, 0xEB);              //0000,0000 PCA Capture 1 Low

SFR(B, 0xF0);                   //0000,0000 B
   SBIT(B0, 0xF0, 0); //B Bit 0
   SBIT(B1, 0xF0, 1); //B Bit 1
   SBIT(B2, 0xF0, 2); //B Bit 2
   SBIT(B3, 0xF0, 3); //B Bit 3
   SBIT(B4, 0xF0, 4); //B Bit 4
   SBIT(B5, 0xF0, 5); //B Bit 5
   SBIT(B6, 0xF0, 6); //B Bit 6
   SBIT(B7, 0xF0, 7); //B Bit 7
   SBIT(B_0, 0xF0, 0); //B Bit 0
   SBIT(B_1, 0xF0, 1); //B Bit 1
   SBIT(B_2, 0xF0, 2); //B Bit 2
   SBIT(B_3, 0xF0, 3); //B Bit 3
   SBIT(B_4, 0xF0, 4); //B Bit 4
   SBIT(B_5, 0xF0, 5); //B Bit 5
   SBIT(B_6, 0xF0, 6); //B Bit 6
   SBIT(B_7, 0xF0, 7); //B Bit 7

SFR(PCA_PWM0, 0xF2);            //xxxx,xx00 Programmable Counter Array Pulse Width Modulator 0
   #define EPC0L 0x01 //PWM 0 Compare Value Low
   #define EPC0H 0x02 //PWM 0 Compare Value High

SFR(PCA_PWM1, 0xF3);            //xxxx,xx00 Programmable Counter Array Pulse Width Modulator 1
   #define EPC1L 0x01 //PWM 1 Compare Value Low
   #define EPC1H 0x02 //PWM 1 Compare Value High

// B7-B2: 保留
// B1(EPCnH): 在 PWM 模式下，与 CCAPnH 组成 9 位数。
// B0(EPCnL): 在 PWM 模式下，与 CCAPnL 组成 9 位数。

// B7-B2: Reserved
// B1 (EPCNH): In PWM mode, it consists of 9 digits with CCAPNH.
// B0 (EPCNL): In the PWM mode, it consists of 9 digits with CCAPNL.

SFR(CH, 0xF9);                  //0000,0000 PCA High

SFR(CCAP0H, 0xFA);              //0000,0000 PCA Capture 0 High

SFR(CCAP1H, 0xFB);              //0000,0000 PCA Capture 1 High

//Interrupt numbers: Address = ( Number * 8 ) + 3
//Vectors are named after their corresponding interrupt
//enable register bit, so that we don't have to make up
//names and can be consisten across different 8051 MCUs
   #define X0_VECTOR  0 // 0x0003 External Interrupt 0
   #define T0_VECTOR  1 // 0x000B Timer 0
   #define X1_VECTOR  2 // 0x0013 External Interrupt 1
   #define T1_VECTOR  3 // 0x001B Timer 1
   #define S_VECTOR   4 // 0x0023 Serial Port
   #define ADC_VECTOR 5 // 0x002B Analog to Digital Converter
   #define LVD_VECTOR 6 // 0x0033 Low Voltage Detect
   #define PCA_VECTOR 7 // 0x003B Programmable Counter Array
   #define S2_VECTOR  8 // 0x0043 Serial Port 2
   #define SPI_VECTOR 9 // 0x004B Serial Peripheral Interface

#endif