// PIO compatible header file STC15-4K-PWM.h 20210829.
// For use with series STC15W4KxxS4 IAP15W4KxxS4 IRC15W4KxxS4
// STC15W1KxxPWM IAP15W1KxxPWM IRC15W1KxxPWM only.
// This header is for newer STC15 MCU's with advanced
// PWM and has been checked against the datasheet.
// The following pins are confgured inputs at POR: 
// P06 P07 P16 P17 P21 P22 P23 P27 P37 P42 P44 P45.

#ifndef STC15_4K_PWM_H
#define STC15_4K_PWM_H
#include <compiler.h>

// Special Function Register | POR Reset Value | Description

SFR(P0, 0x80);                  //1111,1111 Port 0
   SBIT(P00, 0x80, 0); //Port 0 Bit 0
   SBIT(P01, 0x80, 1); //Port 0 Bit 1
   SBIT(P02, 0x80, 2); //Port 0 Bit 2
   SBIT(P03, 0x80, 3); //Port 0 Bit 3
   SBIT(P04, 0x80, 4); //Port 0 Bit 4
   SBIT(P05, 0x80, 5); //Port 0 Bit 5
   SBIT(P06, 0x80, 6); //Port 0 Bit 6
   SBIT(P07, 0x80, 7); //Port 0 Bit 7
   SBIT(P0_0, 0x80, 0); //Port 0 Bit 0
   SBIT(P0_1, 0x80, 1); //Port 0 Bit 1
   SBIT(P0_2, 0x80, 2); //Port 0 Bit 2
   SBIT(P0_3, 0x80, 3); //Port 0 Bit 3
   SBIT(P0_4, 0x80, 4); //Port 0 Bit 4
   SBIT(P0_5, 0x80, 5); //Port 0 Bit 5
   SBIT(P0_6, 0x80, 6); //Port 0 Bit 6
   SBIT(P0_7, 0x80, 7); //Port 0 Bit 7
// See device specific data sheet for additional pin names.

SFR(SP, 0x81);                  //0000,0111 Stack Pointer

SFR(DPTR, 0x82);                //0000,0000 Data Pointer Word
SFR(DPL, 0x82);                 //0000,0000 Data Pointer Low Byte

SFR(DPH, 0x83);                 //0000,0000 Data Pointer High Byte

SFR(S4CON, 0x84);               //0000,0000 Serial Port 4 Control Register
   #define S4RI  0x01 //Serial Port 4 Receive Interrupt Flag
   #define S4TI  0x02 //Serial Port 4 Transmit Interrupt Flag
   #define S4RB8 0x04 //Serial Port 4 Receive Bit 8 Data
   #define S4TB8 0x08 //Serial Port 4 Transmit Bit 8 Data
   #define S4REN 0x10 //Serial Port 4 Receive Enable
   #define S4SM2 0x20 //Serial Port 4 Select Mode Bit 2
   #define S4ST4 0x40 //Serial Port 4 Select Timer 4
   #define S4SM0 0x80 //Serial Port 4 Select Mode Bit 0

SFR(S4BUF, 0x85);               //xxxx,xxxx Serial Port 4 Data Register

SFR(PCON, 0x87);                //0011,0000 Power Control Register
   #define IDL   0x01 //Idle Mode Control
   #define PD    0x02 //Power Down Mode Control
   #define GF0   0x04 //User Defined Gereral Purpose Flag 0
   #define GF1   0x08 //User Defined General Purpose Flag 1
   #define POF   0x10 //Power On Flag
   #define LVDF  0x20 //Low Voltage Detect Flag
   #define SMOD0 0x40 //Frame Error Detection Control
   #define SMOD  0x80 //Double Baudrate of Serial Port 1

SFR(TCON, 0x88);                //0000,0000 T0/T1 Control Register
   SBIT(IT0, 0x88, 0); //Interrupt 0 Type
   SBIT(IE0, 0x88, 1); //Interrupt 0 Edge
   SBIT(IT1, 0x88, 2); //Interrupt 1 Type
   SBIT(IE1, 0x88, 3); //Interrupt 1 Edge
   SBIT(TR0, 0x88, 4); //Timer 0 Run
   SBIT(TF0, 0x88, 5); //Timer 0 Flag
   SBIT(TR1, 0x88, 6); //Timer 1 Run
   SBIT(TF1, 0x88, 7); //Timer 1 Flag

SFR(TMOD, 0x89);                //Timer Mode
   #define T0_M0   0x01 //Timer 0 Mode 0
   #define T0_M1   0x02 //Timer 0 Mode 1
   #define T0_M    0x03 //Timer 0 Mode
   #define T0_CT   0x04 //Timer 0 Counter Timer
   #define T0_GATE 0x08 //Timer 0 Gate
   #define T1_M0   0x10 //Timer 1 Mode 0
   #define T1_M1   0x20 //Timer 1 Mode 1
   #define T1_M    0x30 //Timer 1 Mode
   #define T1_CT   0x40 //Timer 1 Counter Timer
   #define T1_GATE 0x80 //Timer 1 Gate
   #define M00   0x01 //Mode 0 Timer 0
   #define M10   0x02 //Mode 1 Timer 0
   #define M0    0x03 //Timer 0 Mode
   #define CT0   0x04 //Counter Timer 0
   #define GATE0 0x08 //Gate 0
   #define M01   0x10 //Mode 1 Timer 1
   #define M11   0x20 //Mode 1 Timer 1
   #define M1    0x30 //Timer 1 Mode
   #define CT1   0x40 //Counter Timer 1
   #define GATE1 0x80 //Gate 1

SFR(TL0, 0x8A);                 //0000,0000 Timer 0 Low Byte
SFR(RL_TL0, 0x8A);              //0000,0000 Reload Timer 0 Low Byte

SFR(TL1, 0x8B);                 //0000,0000 Timer 1 Low Byte
SFR(RL_TL1, 0x8B);              //0000,0000 Reload Timer 1 Low Byte

SFR(TH0, 0x8C);                 //0000,0000 Timer 0 High Byte
SFR(RL_TH0, 0x8C);              //0000,0000 Reload Timer 0 High Byte

SFR(TH1, 0x8D);                 //0000,0000 Timer 1 High Byte
SFR(RL_TH1, 0x8D);              //0000,0000 Reload Timer 1 High Byte

SFR(AUXR, 0x8E);                //0000,0001 Auxiliary Register
   #define S1ST2     0x01 //Serial Port 1 Baud Rate Generator Select
   #define EXTRAM    0x02 //Extended RAM Access Control
   #define T2x12     0x04 //Timer 2 Clock x12 Prescaler Bypass
   #define T2_CT     0x08 //Timer 2 Counter or Timer Mode Select
   #define T2R       0x10 //Timer 2 Run Control
   #define UART_M0x6 0x20 //UART 1 Mode 0 Baudrate Prescaler Select
   #define T1x12     0x40 //Timer 1 Clock x12 Prescaler Bypass
   #define T0x12     0x80 //Timer 0 Clock x12 Prescaler Bypass

SFR(INT_CLKO, 0x8F);            //x000,0000|0000,0000 Interrupt and Clock Output Control Register
SFR(AUXR2, 0x8F);               //Auxiliary Register 2
   #define T0CLKO  0x01 //Timer 0 Clock Output Control
   #define T1CLKO  0x02 //Timer 1 Clock Output Control
   #define T2CLKO  0x04 //Timer 2 Clock Output Control
   #define MCKO_S2 0x08 //Master Clock Output Select 2 (see register 0x97)
   #define EX2     0x10 //External Interrupt 3 Enable
   #define EX3     0x20 //External Interrupt 2 Enable
   #define EX4     0x40 //External Interrupt 4 Enable

SFR(P1, 0x90);                  //1111,1111 Port 1
   SBIT(ACH0, 0x90, 0); //ADC Channel 0
   SBIT(ACH1, 0x90, 1); //ADC Channel 1
   SBIT(ACH2, 0x90, 2); //ADC Channel 2
   SBIT(ACH3, 0x90, 3); //ADC Channel 3
   SBIT(ACH4, 0x90, 4); //ADC Channel 4
   SBIT(ACH5, 0x90, 5); //ADC Channel 5
   SBIT(ACH6, 0x90, 6); //ADC Channel 6
   SBIT(ACH7, 0x90, 7); //ADC Channel 7
   SBIT(ADC0, 0x90, 0); //AtoD Channel 0
   SBIT(ADC1, 0x90, 1); //AtoD Channel 1
   SBIT(ADC2, 0x90, 2); //AtoD Channel 2
   SBIT(ADC3, 0x90, 3); //AtoD Channel 3
   SBIT(ADC4, 0x90, 4); //AtoD Channel 4
   SBIT(ADC5, 0x90, 5); //AtoD Channel 5
   SBIT(ADC6, 0x90, 6); //AtoD Channel 6
   SBIT(ADC7, 0x90, 7); //AtoD Channel 7
   SBIT(AIN0, 0x90, 0); //Analog Input 0
   SBIT(AIN1, 0x90, 1); //Analog Input 1
   SBIT(AIN2, 0x90, 2); //Analog Input 2
   SBIT(AIN3, 0x90, 3); //Analog Input 3
   SBIT(AIN4, 0x90, 4); //Analog Input 4
   SBIT(AIN5, 0x90, 5); //Analog Input 5
   SBIT(AIN6, 0x90, 6); //Analog Input 6
   SBIT(AIN7, 0x90, 7); //Analog Input 7
   SBIT(P10, 0x90, 0); //Port 1 Bit 0
   SBIT(P11, 0x90, 1); //Port 1 Bit 1
   SBIT(P12, 0x90, 2); //Port 1 Bit 2
   SBIT(P13, 0x90, 3); //Port 1 Bit 3
   SBIT(P14, 0x90, 4); //Port 1 Bit 4
   SBIT(P15, 0x90, 5); //Port 1 Bit 5
   SBIT(P16, 0x90, 6); //Port 1 Bit 6
   SBIT(P17, 0x90, 7); //Port 1 Bit 7
   SBIT(P1_0, 0x90, 0); //Port 1 Bit 0
   SBIT(P1_1, 0x90, 1); //Port 1 Bit 1
   SBIT(P1_2, 0x90, 2); //Port 1 Bit 2
   SBIT(P1_3, 0x90, 3); //Port 1 Bit 3
   SBIT(P1_4, 0x90, 4); //Port 1 Bit 4
   SBIT(P1_5, 0x90, 5); //Port 1 Bit 5
   SBIT(P1_6, 0x90, 6); //Port 1 Bit 6
   SBIT(P1_7, 0x90, 7); //Port 1 Bit 7
// See device specific data sheet for additional pin names.

SFR(P1M1, 0x91);                //0000,0000 Port 1 Mode Register 1
   #define P10M1 0x01 //Port 1 bit 0 Mode 1
   #define P11M1 0x02 //Port 1 bit 1 Mode 1
   #define P12M1 0x04 //Port 1 bit 2 Mode 1
   #define P13M1 0x08 //Port 1 bit 3 Mode 1
   #define P14M1 0x10 //Port 1 bit 4 Mode 1
   #define P15M1 0x20 //Port 1 bit 5 Mode 1
   #define P16M1 0x40 //Port 1 bit 6 Mode 1
   #define P17M1 0x80 //Port 1 bit 7 Mode 1

SFR(P1M0, 0x92);                //0000,0000 Port 1 Mode Register 0
   #define P10M0 0x01 //Port 1 bit 0 Mode 0
   #define P11M0 0x02 //Port 1 bit 1 Mode 0
   #define P12M0 0x04 //Port 1 bit 2 Mode 0
   #define P13M0 0x08 //Port 1 bit 3 Mode 0
   #define P14M0 0x10 //Port 1 bit 4 Mode 0
   #define P15M0 0x20 //Port 1 bit 5 Mode 0
   #define P16M0 0x40 //Port 1 bit 6 Mode 0
   #define P17M0 0x80 //Port 1 bit 7 Mode 0

SFR(P0M1, 0x93);                //0000,0000 Port 0 Mode Register 1
   #define P00M1 0x01 //Port 0 bit 0 Mode 1
   #define P01M1 0x02 //Port 0 bit 1 Mode 1
   #define P02M1 0x04 //Port 0 bit 2 Mode 1
   #define P03M1 0x08 //Port 0 bit 3 Mode 1
   #define P04M1 0x10 //Port 0 bit 4 Mode 1
   #define P05M1 0x20 //Port 0 bit 5 Mode 1
   #define P06M1 0x40 //Port 0 bit 6 Mode 1
   #define P07M1 0x80 //Port 0 bit 7 Mode 1

SFR(P0M0, 0x94);                //0000,0000 Port 0 Mode Register 0
   #define P00M0 0x01 //Port 0 bit 0 Mode 0
   #define P01M0 0x02 //Port 0 bit 1 Mode 0
   #define P02M0 0x04 //Port 0 bit 2 Mode 0
   #define P03M0 0x08 //Port 0 bit 3 Mode 0
   #define P04M0 0x10 //Port 0 bit 4 Mode 0
   #define P05M0 0x20 //Port 0 bit 5 Mode 0
   #define P06M0 0x40 //Port 0 bit 6 Mode 0
   #define P07M0 0x80 //Port 0 bit 7 Mode 0

SFR(P2M1, 0x95);                //0000,0000 Port 2 Mode Register 1
   #define P20M1 0x01 //Port 2 bit 0 Mode 1
   #define P21M1 0x02 //Port 2 bit 1 Mode 1
   #define P22M1 0x04 //Port 2 bit 2 Mode 1
   #define P23M1 0x08 //Port 2 bit 3 Mode 1
   #define P24M1 0x10 //Port 2 bit 4 Mode 1
   #define P25M1 0x20 //Port 2 bit 5 Mode 1
   #define P26M1 0x40 //Port 2 bit 6 Mode 1
   #define P27M1 0x80 //Port 2 bit 7 Mode 1

SFR(P2M0, 0x96);                //0000,0000 Port 2 Mode Register 0
   #define P20M0 0x01 //Port 2 bit 0 Mode 0
   #define P21M0 0x02 //Port 2 bit 1 Mode 0
   #define P22M0 0x04 //Port 2 bit 2 Mode 0
   #define P23M0 0x08 //Port 2 bit 3 Mode 0
   #define P24M0 0x10 //Port 2 bit 4 Mode 0
   #define P25M0 0x20 //Port 2 bit 5 Mode 0
   #define P26M0 0x40 //Port 2 bit 6 Mode 0
   #define P27M0 0x80 //Port 2 bit 7 Mode 0

SFR(CLK_DIV, 0x97);             //0000,0000 Clock Division Control Register
SFR(PCON2, 0x97);               //Power Control Register 2
   #define CLKS0 0x01 //Clock Select 0
   #define CLKS1 0x02 //Clock Select 1
   #define CLKS2 0x04 //Clock Select 2
   #define CLKS  0x07 //Clock Select
   #define MCLKO_2 0x08 //Master Clock Output 2 Select
   #define Tx_Rx   0x10 //Relay from Rx out to Tx
   #define ADRJ    0x20 //Analog to Digital Result Juxtapose
   #define MCKO_S0 0x40 //Master Clock Output Select 0 (see register 0x8F)
   #define MCKO_S1 0x80 //Master Clock Output Select 1 (see register 0x8F)

SFR(SCON, 0x98);                //0000,0000 Serial Port 1 Control Register
   SBIT(RI,  0x98, 0); //Receive Interrupt
   SBIT(TI,  0x98, 1); //Transmit Interrupt
   SBIT(RB8, 0x98, 2); //Receive Bit 8
   SBIT(TB8, 0x98, 3); //Transmit Bit 8
   SBIT(REN, 0x98, 4); //Receive Enable
   SBIT(SM2, 0x98, 5); //Serial Mode 2
   SBIT(SM1, 0x98, 6); //Serial Mode 1
   SBIT(SM0, 0x98, 7); //Serial Mode 0
   SBIT(FE,  0x98, 7); //Framing Error

SFR(SBUF, 0x99);                //xxxx,xxxx Serial Port 1 Data Register

SFR(S2CON, 0x9A);               //0100,0000|0000,0000 Serial Port 2 Control Register
   #define S2RI  0x01 //Serial Port 2 Receive Interrupt Flag
   #define S2TI  0x02 //Serial Port 2 Transmit Interrupt Flag
   #define S2RB8 0x04 //Serial Port 2 Receive Bit 8 Data
   #define S2TB8 0x08 //Serial Port 2 Transmit Bit 8 Data
   #define S2REN 0x10 //Serial Port 2 Receive Enable
   #define S2SM2 0x20 //Serial Port 2 Select Mode Bit 2
   #define S2SM0 0x80 //Serial Port 2 Select Mode Bit 0

SFR(S2BUF, 0x9B);               //xxxx,xxxx Serial Port 2 Data Register

SFR(P1ASF, 0x9D);               //0000,0000 Port 1 Analog Function Configuration Register
   #define P10ASF 0x01 //Port 1 bit 0 Analog Special Function
   #define P11ASF 0x02 //Port 1 bit 1 Analog Special Function
   #define P12ASF 0x04 //Port 1 bit 2 Analog Special Function
   #define P13ASF 0x08 //Port 1 bit 3 Analog Special Function
   #define P14ASF 0x10 //Port 1 bit 4 Analog Special Function
   #define P15ASF 0x20 //Port 1 bit 5 Analog Special Function
   #define P16ASF 0x40 //Port 1 bit 6 Analog Special Function
   #define P17ASF 0x80 //Port 1 bit 7 Analog Special Function

SFR(P2, 0xA0);                  //1111,1111 Port 2
   SBIT(P20, 0xA0, 0); //Port 2 Bit 0
   SBIT(P21, 0xA0, 1); //Port 2 Bit 1
   SBIT(P22, 0xA0, 2); //Port 2 Bit 2
   SBIT(P23, 0xA0, 3); //Port 2 Bit 3
   SBIT(P24, 0xA0, 4); //Port 2 Bit 4
   SBIT(P25, 0xA0, 5); //Port 2 Bit 5
   SBIT(P26, 0xA0, 6); //Port 2 Bit 6
   SBIT(P27, 0xA0, 7); //Port 2 Bit 7
   SBIT(P2_0, 0xA0, 0); //Port 2 Bit 0
   SBIT(P2_1, 0xA0, 1); //Port 2 Bit 1
   SBIT(P2_2, 0xA0, 2); //Port 2 Bit 2
   SBIT(P2_3, 0xA0, 3); //Port 2 Bit 3
   SBIT(P2_4, 0xA0, 4); //Port 2 Bit 4
   SBIT(P2_5, 0xA0, 5); //Port 2 Bit 5
   SBIT(P2_6, 0xA0, 6); //Port 2 Bit 6
   SBIT(P2_7, 0xA0, 7); //Port 2 Bit 7
// See device specific data sheet for additional pin names.

SFR(BUS_SPEED, 0xA1);           //xxxx,xx10 Bus Speed Control Register
   #define SPEED 0x07 //Bus Read-Write Speed Control
   #define RW_S  0xC0 //Read-Write Control Pin Select

SFR(P_SW1, 0xA2);               //0100,0000|0000,0000 Peripheral Port Switching Register 1
SFR(AUXR1, 0xA2);               //Auxiliary Register 1
   #define DPS    0x01 //Data Pointer Select
   #define SPI_S0 0x04 //Serial Peripheral Interface Select 0
   #define SPI_S1 0x08 //Serial Peripheral Interface Select 1
   #define SPI_S  0x0C //Serial Peripheral Interface Select
   #define CCP_S0 0x10 //Compare Capture PWM Select 0
   #define CCP_S1 0x20 //Compare Capture PWM Select 1
   #define CCP_S  0x30 //Compare Capture PWM Select
   #define S1_S0  0x40 //Serial Port 1 Select 0
   #define S1_S1  0x80 //Serial Port 1 Select 1
   #define S1_S   0xC0 //Serial Purt 1 Select

SFR(IE, 0xA8);                  //0000,0000 Interrupt Control Register
   SBIT(EX0,  0xA8, 0); //Enable External 0
   SBIT(ET0,  0xA8, 1); //Enable Timer 0
   SBIT(EX1,  0xA8, 2); //Enable External 1
   SBIT(ET1,  0xA8, 3); //Enable Timer 1
   SBIT(ES,   0xA8, 4); //Enable Serial
   SBIT(EADC, 0xA8, 5); //Enable ADC
   SBIT(ELVD, 0xA8, 6); //Enable Low Voltage Detect
   SBIT(EA,   0xA8, 7); //Enable All

SFR(SADDR, 0xA9);               //0000,0000 Slave Address Register

SFR(WKTCL, 0xAA);               //0111,1111|1111,1111 Power Down Wakeup Timer Control Low Byte
SFR(WKTCL_CNT, 0xAA);           //0111,1111|1111,1111 Power Down Wakeup Timer Control Count

SFR(WKTCH, 0xAB);               //0111,1111 Power Down Wakeup Timer Control High Byte
   #define WKTEN 0x80 //Power Down Wakeup Timer Enable
SFR(WKTCH_CNT, 0xAB);           //0111,1111|x111,1111 Power Down Wakeup Timer Control Count

SFR(S3CON, 0xAC);               //0000,0000 Serial Port 3 Control Register
   #define S3RI  0x01 //Serial Port 3 Receive Interrupt Flag
   #define S3TI  0x02 //Serial Port 3 Transmit Interrupt Flag
   #define S3RB8 0x04 //Serial Port 3 Receive Bit 8 Data
   #define S3TB8 0x08 //Serial Port 3 Transmit Bit 8 Data
   #define S3REN 0x10 //Serial Port 3 Receive Enable
   #define S3SM2 0x20 //Serial Port 3 Select Mode Bit 2
   #define S3ST3 0x40 //Serial Port 3 Select Timer 3
   #define S3SM0 0x80 //Serial Port 3 Select Mode Bit 0

SFR(S3BUF, 0xAD);               //xxxx,xxxx Serial Port 3 Data Register

SFR(IE2, 0xAF);                 //x000,0000 Interrupt Enable Register 2
   #define ES2  0x01 //Enable Serial Port 2 Interrupt
   #define ESPI 0x02 //Enable Serial Peripheral Interface Interrupt
   #define ET2  0x04 //Enable Timer 2 Interrupt
   #define ES3  0x08 //Enable Serial Port 3 Interrupt
   #define ES4  0x10 //Enable Serial Port 4 Interrupt
   #define ET3  0x20 //Enable Timer 3 Interrupt
   #define ET4  0x40 //Enable Timer 4 Interrupt
   #define ECAN 0x80 //Enable CAN Interrupt

SFR(P3, 0xB0);                  //1111,1111 Port 3
   SBIT(P30, 0xB0, 0); //Port 3 Bit 0
   SBIT(P31, 0xB0, 1); //Port 3 Bit 1
   SBIT(P32, 0xB0, 2); //Port 3 Bit 2
   SBIT(P33, 0xB0, 3); //Port 3 Bit 3
   SBIT(P34, 0xB0, 4); //Port 3 Bit 4
   SBIT(P35, 0xB0, 5); //Port 3 Bit 5
   SBIT(P36, 0xB0, 6); //Port 3 Bit 6
   SBIT(P37, 0xB0, 7); //Port 3 Bit 7
   SBIT(P3_0, 0xB0, 0); //Port 3 Bit 0
   SBIT(P3_1, 0xB0, 1); //Port 3 Bit 1
   SBIT(P3_2, 0xB0, 2); //Port 3 Bit 2
   SBIT(P3_3, 0xB0, 3); //Port 3 Bit 3
   SBIT(P3_4, 0xB0, 4); //Port 3 Bit 4
   SBIT(P3_5, 0xB0, 5); //Port 3 Bit 5
   SBIT(P3_6, 0xB0, 6); //Port 3 Bit 6
   SBIT(P3_7, 0xB0, 7); //Port 3 Bit 7
// See device specific data sheet for additional pin names.

SFR(P3M1, 0xB1);                //0000,0000 Port 3 Mode Register 1
   #define P30M1 0x01 //Port 3 bit 0 Mode 1
   #define P31M1 0x02 //Port 3 bit 1 Mode 1
   #define P32M1 0x04 //Port 3 bit 2 Mode 1
   #define P33M1 0x08 //Port 3 bit 3 Mode 1
   #define P34M1 0x10 //Port 3 bit 4 Mode 1
   #define P35M1 0x20 //Port 3 bit 5 Mode 1
   #define P36M1 0x40 //Port 3 bit 6 Mode 1
   #define P37M1 0x80 //Port 3 bit 7 Mode 1

SFR(P3M0, 0xB2);                //0000,0000 Port 3 Mode Register 0
   #define P30M0 0x01 //Port 3 bit 0 Mode 0
   #define P31M0 0x02 //Port 3 bit 1 Mode 0
   #define P32M0 0x04 //Port 3 bit 2 Mode 0
   #define P33M0 0x08 //Port 3 bit 3 Mode 0
   #define P34M0 0x10 //Port 3 bit 4 Mode 0
   #define P35M0 0x20 //Port 3 bit 5 Mode 0
   #define P36M0 0x40 //Port 3 bit 6 Mode 0
   #define P37M0 0x80 //Port 3 bit 7 Mode 0

SFR(P4M1, 0xB3);                //0000,0000 Port 4 Mode Register 1
   #define P40M1 0x01 //Port 4 bit 0 Mode 1
   #define P41M1 0x02 //Port 4 bit 1 Mode 1
   #define P42M1 0x04 //Port 4 bit 2 Mode 1
   #define P43M1 0x08 //Port 4 bit 3 Mode 1
   #define P44M1 0x10 //Port 4 bit 4 Mode 1
   #define P45M1 0x20 //Port 4 bit 5 Mode 1
   #define P46M1 0x40 //Port 4 bit 6 Mode 1
   #define P47M1 0x80 //Port 4 bit 7 Mode 1

SFR(P4M0, 0xB4);                //0000,0000 Port 4 Mode Register 0
   #define P40M0 0x01 //Port 4 bit 0 Mode 0
   #define P41M0 0x02 //Port 4 bit 1 Mode 0
   #define P42M0 0x04 //Port 4 bit 2 Mode 0
   #define P43M0 0x08 //Port 4 bit 3 Mode 0
   #define P44M0 0x10 //Port 4 bit 4 Mode 0
   #define P45M0 0x20 //Port 4 bit 5 Mode 0
   #define P46M0 0x40 //Port 4 bit 6 Mode 0
   #define P47M0 0x80 //Port 4 bit 7 Mode 0

SFR(IP2, 0xB5);                 //xxx0,0000|xx00,0000|0000,0000 Interrupt Priority Register 2
   #define PS2    0x01 //Serial Port 2 Interrupt Priority
   #define PSPI   0x02 //Serial Peripheral Interface Interrupt Priority
   #define PPWM   0x04 //PWM Interrupt Priority
   #define PPWMFD 0x08 //PWM Fault Detect Interrupt Priority
   #define PX4    0x10 //External Interrupt 4 Priority
   #define PCMP   0x20 //Comparator Interrupt Priority
   #define PI2C   0x40 //I2C Interrupt Priority
   #define PCAN   0x80 //CAN Interrupt Priority

// SFR(IP2H, 0xB6); //Datasheet Error?
// SFR(IPH, 0xB7); //Datasheet Error?

SFR(IP, 0xB8);                  //0000,0000|x0x0,0000 Interrupt Priority Register
   SBIT(PX0,  0xB8, 0); //Priority External 0
   SBIT(PT0,  0xB8, 1); //Priority Timer 0
   SBIT(PX1,  0xB8, 2); //Priority External 1
   SBIT(PT1,  0xB8, 3); //Priority Timer 1
   SBIT(PS,   0xB8, 4); //Priority Serial
   SBIT(PADC, 0xB8, 5); //Priority ADC
   SBIT(PLVD, 0xB8, 6); //Priority Low Voltage Detect
   SBIT(PPCA, 0xB8, 7); //Priority Programmable Counter Array

SFR(SADEN, 0xB9);               //0000,0000 Slave Address Mask Register

SFR(P_SW2, 0xBA);               //0000,x000|xxxx,x000|0000,0000 Peripheral Port Switching Register 2
   #define S2_S   0x10 //Serial Port 2 Pin Select
   #define S3_S   0x20 //Serial Port 3 Pin Select
   #define S4_S   0x40 //Serial Port 4 Pin Select
   #define CMPO_S 0x80 //Comparator Output Pin Select
   #define I2C_S  0x30 //I2C Pin Select
   #define CAN_S  0x40 //CAN Pin Select
   #define EAXFR  0x80 //Extended RAM Area Transfer Enable

SFR(ADC_CONTR, 0xBC);           //0000,0000 ADC Conversion Control Register
   #define CHS0      0x01 //Channel Select 0
   #define CHS1      0x02 //Channel Select 1
   #define CHS2      0x04 //Channel Select 2
   #define ADC_CHS   0x0F //ADC Analog Channel Select
   #define ADC_START 0x08 //Analog to Digital Converter Start
   #define ADC_FLAG  0x10 //Analog to Digital Converter Flag
   #define SPEED0    0x20 //Speed 0
   #define SPEED1    0x40 //Speed 1
   #define ADC_POWER 0x80 //Analog to Digital Converter Power

SFR(ADC_RES, 0xBD);             //0000,0000 ADC Conversion Result High 8 Bits

SFR(ADC_RESL, 0xBE);            //0000,0000 ADC Conversion Result Low 2 Bits

SFR(P4, 0xC0);                  //1111,1111 Port 4
   SBIT(P40,  0xC0, 0); //Port 4 Bit 0
   SBIT(P41,  0xC0, 1); //Port 4 Bit 1
   SBIT(P42,  0xC0, 2); //Port 4 Bit 2
   SBIT(P43,  0xC0, 3); //Port 4 Bit 3
   SBIT(P44,  0xC0, 4); //Port 4 Bit 4
   SBIT(P45,  0xC0, 5); //Port 4 Bit 5
   SBIT(P46,  0xC0, 6); //Port 4 Bit 6
   SBIT(P47,  0xC0, 7); //Port 4 Bit 7
   SBIT(P4_0,  0xC0, 0); //Port 4 Bit 0
   SBIT(P4_1,  0xC0, 1); //Port 4 Bit 1
   SBIT(P4_2,  0xC0, 2); //Port 4 Bit 2
   SBIT(P4_3,  0xC0, 3); //Port 4 Bit 3
   SBIT(P4_4,  0xC0, 4); //Port 4 Bit 4
   SBIT(P4_5,  0xC0, 5); //Port 4 Bit 5
   SBIT(P4_6,  0xC0, 6); //Port 4 Bit 6
   SBIT(P4_7,  0xC0, 7); //Port 4 Bit 7
// See device specific data sheet for additional pin names.

SFR(WDT_CONTR, 0xC1);           //xx00,0000|0x00,0000 Watchdog Control Register
   #define WDTPS0   0x01 //Watchdog Timer Prescaler 0
   #define WDTPS1   0x02 //Watchdog Timer Prescaler 1
   #define WDTPS2   0x04 //Watchdog Timer Prescaler 2
   #define WDT_PS   0x07 //Watchdog Timer Prescaler
   #define IDL_WDT  0x08 //Watchdog Timer Idle Mode Behavior
   #define CLR_WDT  0x10 //Clear Watchdog Timer
   #define EN_WDT   0x20 //Enable Watchdog Timer
   #define WDT_FLAG 0x80 //Watchdog Timer Overflow Flag

SFR(IAP_DATA, 0xC2);            //1111,1111 In Application Programming Data
SFR(ISP_DATA, 0xC2);            //In System Programming Data

SFR(IAP_ADDRH, 0xC3);           //0000,0000 In Application Programming Address High
SFR(ISP_ADDRH, 0xC3);           //In System Programming Address High

SFR(IAP_ADDRL, 0xC4);           //0000,0000 In Application Programming Address Low
SFR(ISP_ADDRL, 0xC4);           //In System Programming Address Low

SFR(IAP_CMD, 0xC5);             //xxxx,x000|xxxx,xx00 In Application Programming Command
SFR(ISP_CMD, 0xC5);             //In System Programming Command
   #define MS0    0x01 //Mode Select 0
   #define MS1    0x02 //Mode Select 1
   #define IAPCMD 0x03 //In Application Programming Command
// Valid commands follow
#define IAP_IDL   0x00
#define IAP_READ  0x01
#define IAP_WRITE 0x02
#define IAP_ERASE 0x03
// End of valid commands

SFR(IAP_TRIG, 0xC6);            //xxxx,xxxx In Application Programming Trigger
SFR(ISP_TRIG, 0xC6);            //In System Programming Trigger

SFR(IAP_CONTR, 0xC7);           //0000,x000|0000,0000 In Application Programming Control
SFR(ISP_CONTR, 0xC7);           //In System Programming Control
   #define WT0      0x01 //Wait 0
   #define WT1      0x02 //Wait 1
   #define WT2      0x04 //Wait 2
   #define IAP_WT   0x07 //In Application Programming Wait
   #define CMD_FAIL 0x10 //Command Fail
   #define SWRST    0x20 //Software Reset Trigger
   #define SWBS     0x40 //Software Boot Selection
   #define IAPEN    0x80 //In Application Programming Enable

SFR(P5, 0xC8);                  //xxxx,1111 Port 5
   SBIT(P50,  0xC8, 0); //Port 5 Bit 0
   SBIT(P51,  0xC8, 1); //Port 5 Bit 1
   SBIT(P52,  0xC8, 2); //Port 5 Bit 2
   SBIT(P53,  0xC8, 3); //Port 5 Bit 3
   SBIT(P54,  0xC8, 4); //Port 5 Bit 4
   SBIT(P55,  0xC8, 5); //Port 5 Bit 5
   SBIT(P5_0,  0xC8, 0); //Port 5 Bit 0
   SBIT(P5_1,  0xC8, 1); //Port 5 Bit 1
   SBIT(P5_2,  0xC8, 2); //Port 5 Bit 2
   SBIT(P5_3,  0xC8, 3); //Port 5 Bit 3
   SBIT(P5_4,  0xC8, 4); //Port 5 Bit 4
   SBIT(P5_5,  0xC8, 5); //Port 5 Bit 5
// See device specific data sheet for additional pin names.

SFR(P5M1, 0xC9);                //0000,0000|xxxx,1111 Port 5 Mode Register 1
   #define P50M1 0x01 //Port 5 bit 0 Mode 1
   #define P51M1 0x02 //Port 5 bit 1 Mode 1
   #define P52M1 0x04 //Port 5 bit 2 Mode 1
   #define P53M1 0x08 //Port 5 bit 3 Mode 1
   #define P54M1 0x10 //Port 5 bit 4 Mode 1
   #define P55M1 0x20 //Port 5 bit 5 Mode 1

SFR(P5M0, 0xCA);                //0000,0000|xxxx,1111 Port 5 Mode Register 0
   #define P50M0 0x01 //Port 5 bit 0 Mode 0
   #define P51M0 0x02 //Port 5 bit 1 Mode 0
   #define P52M0 0x04 //Port 5 bit 2 Mode 0
   #define P53M0 0x08 //Port 5 bit 3 Mode 0
   #define P54M0 0x10 //Port 5 bit 4 Mode 0
   #define P55M0 0x20 //Port 5 bit 5 Mode 0

SFR(P6M1, 0xCB);                //0000,0000 Port 6 Mode Register 1
   #define P60M1 0x01 //Port 6 bit 0 Mode 1
   #define P61M1 0x02 //Port 6 bit 1 Mode 1
   #define P62M1 0x04 //Port 6 bit 2 Mode 1
   #define P63M1 0x08 //Port 6 bit 3 Mode 1
   #define P64M1 0x10 //Port 6 bit 4 Mode 1
   #define P65M1 0x20 //Port 6 bit 5 Mode 1
   #define P66M1 0x40 //Port 6 bit 6 Mode 1
   #define P67M1 0x80 //Port 6 bit 7 Mode 1

SFR(P6M0, 0xCC);                //0000,0000 Port 6 Mode Register 0
   #define P60M0 0x01 //Port 6 bit 0 Mode 0
   #define P61M0 0x02 //Port 6 bit 1 Mode 0
   #define P62M0 0x04 //Port 6 bit 2 Mode 0
   #define P63M0 0x08 //Port 6 bit 3 Mode 0
   #define P64M0 0x10 //Port 6 bit 4 Mode 0
   #define P65M0 0x20 //Port 6 bit 5 Mode 0
   #define P66M0 0x40 //Port 6 bit 6 Mode 0
   #define P67M0 0x80 //Port 6 bit 7 Mode 0

SFR(SPSTAT, 0xCD);              //00xx,xxxx Serial Peripheral Status Register
   #define WCOL 0x40 //Write Collision
   #define SPIF 0x80 //Serial Peripheral Interface Flag

SFR(SPCTL, 0xCE);               //0000,0100 Serial Peripheral Control
   #define SPR0 0x00 //Serial Peripheral Rate 0
   #define SPR1 0x01 //Serial Peripheral Rate 1
   #define SPR  0x03 //Serial Peripheral Rate
   #define CPHA 0x04 //Clock Phase
   #define CPOL 0x08 //Clock Polarity
   #define MSTR 0x10 //Master
   #define DORD 0x20 //Data Order
   #define SPEN 0x40 //Serial Peripheral Enable
   #define SSIG 0x80 //Slave Select Signal

SFR(SPDAT, 0xCF);               //0000,0000 Serial Peripheral Data Register

SFR(PSW, 0xD0);                 //0000,0000 Program status word
   SBIT(P,   0xD0, 0); //Parity
   SBIT(F1,  0xD0, 1); //Flag 1
   SBIT(OV,  0xD0, 2); //Overflow
   SBIT(RS0, 0xD0, 3); //Register Select 0
   SBIT(RS1, 0xD0, 4); //Register Select 1
   SBIT(F0,  0xD0, 5); //Flag 0
   SBIT(AC,  0xD0, 6); //Auxiliary Carry
   SBIT(CY,  0xD0, 7); //Carry

SFR(T4T3M, 0xD1);               //0000,0000 T3/T4 Mode Register
   #define T3CLKO 0x01 //Timer 3 Clock Output Control
   #define T3x12  0x02 //Timer 3 Clock x12 Prescaler Bypass
   #define T3_CT  0x04 //Timer 3 Counter or Timer Mode Select
   #define T3R    0x08 //Timer 3 Run Control
   #define T4CLKO 0x10 //Timer 4 Clock Output Control
   #define T4x12  0x20 //Timer 4 Clock x12 Prescaler Bypass
   #define T4_CT  0x40 //Timer 4 Counter or Timer Mode Select
   #define T4R    0x80 //Timer 4 Run Control

SFR(T4H, 0xD2);                 //0000,0000 Timer 4 High Byte
SFR(RL_TH4, 0xD2);              //0000,0000 Reload Timer 4 High Byte

SFR(T4L, 0xD3);                 //0000,0000 Timer 4 Low Byte
SFR(RL_TL4, 0xD3);              //0000,0000 Reload Timer 4 Low Byte

SFR(T3H, 0xD4);                 //0000,0000 Timer 3 High Byte
SFR(RL_TH3, 0xD4);              //0000,0000 Reload Timer 3 High Byte

SFR(T3L, 0xD5);                 //0000,0000 Timer 3 Low Byte
SFR(RL_TL3, 0xD5);              //0000,0000 Reload Timer 3 Low Byte

SFR(T2H, 0xD6);                 //0000,0000 Timer 2 High Byte
SFR(RL_TH2, 0xD6);              //0000,0000 Reload Timer 2 High Byte

SFR(T2L, 0xD7);                 //0000,0000 Timer 2 Low Byte
SFR(RL_TL2, 0xD7);              //0000,0000 Reload Timer 2 Low Byte

SFR(CCON, 0xD8);                //00xx,0000|00xx,xx00 PCA Control Register
   SBIT(CCF0, 0xD8, 0); //Capture Compare Flag 0
   SBIT(CCF1, 0xD8, 1); //Capture Compare Flag 1
   SBIT(CCF2, 0xD8, 2); //Capture Compare Flag 2
   SBIT(CCF3, 0xD8, 3); //Capture Compare Flag 3
   SBIT(CR,   0xD8, 6); //PCA Run
   SBIT(CF,   0xD8, 7); //PCA Flag

SFR(CMOD, 0xD9);                //00xx,0000|0xxx,0000|0xxx,x000 PCA Working Mode Register
   #define ECF  0x01 //PCA Counter Overflow Interrupt Enable
   #define CPS0 0x02 //PCA Counter Pulse Source Select 0
   #define CPS1 0x04 //PCA Counter Pulse Source Select 1
   #define CPS2 0x08 //PCA Counter Pulse Source Select 2
   #define CPS  0x0E //PCA Counter Pulse Source Select
   #define CIDL 0x80 //PCA Counter Idle Mode Control

SFR(CCAPM0, 0xDA);              //x000,0000 Compare Capture PWM 0 Mode
   #define ECCF0  0x01 //Enable PCA Capture Flag 0
   #define PWM0   0x02 //Pulse Width Modulator 0
   #define TOG0   0x04 //Toggle 0
   #define MAT0   0x08 //Match 0
   #define CCAPN0 0x10 //PCA Capture Negative-going 0
   #define CCAPP0 0x20 //PCA Capture Positive-going 0
   #define ECOM0  0x40 //Enable Comparator 0

SFR(CCAPM1, 0xDB);              //x000,0000 Compare Capture PWM 1 Mode
   #define ECCF1  0x01 //Enable PCA Capture Flag 1
   #define PWM1   0x02 //Pulse Width Modulator 1
   #define TOG1   0x04 //Toggle 1
   #define MAT1   0x08 //Match 1
   #define CCAPN1 0x10 //PCA Capture Negative-going 1
   #define CCAPP1 0x20 //PCA Capture Positive-going 1
   #define ECOM1  0x40 //Enable Comparator 1

SFR(ACC, 0xE0);                 //0000,0000 Accumulator
   SBIT(ACC0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC7, 0xE0, 7); //Accumulator Bit 7
   SBIT(ACC_0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC_1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC_2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC_3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC_4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC_5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC_6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC_7, 0xE0, 7); //Accumulator Bit 7

SFR(P7M1, 0xE1);                //0000,0000 Port 7 Mode Register 1
   #define P70M1 0x01 //Port 7 bit 0 Mode 1
   #define P71M1 0x02 //Port 7 bit 1 Mode 1
   #define P72M1 0x04 //Port 7 bit 2 Mode 1
   #define P73M1 0x08 //Port 7 bit 3 Mode 1
   #define P74M1 0x10 //Port 7 bit 4 Mode 1
   #define P75M1 0x20 //Port 7 bit 5 Mode 1
   #define P76M1 0x40 //Port 7 bit 6 Mode 1
   #define P77M1 0x80 //Port 7 bit 7 Mode 1

SFR(P7M0, 0xE2);                //0000,0000 Port 7 Mode Register 0
   #define P70M0 0x01 //Port 7 bit 0 Mode 0
   #define P71M0 0x02 //Port 7 bit 1 Mode 0
   #define P72M0 0x04 //Port 7 bit 2 Mode 0
   #define P73M0 0x08 //Port 7 bit 3 Mode 0
   #define P74M0 0x10 //Port 7 bit 4 Mode 0
   #define P75M0 0x20 //Port 7 bit 5 Mode 0
   #define P76M0 0x40 //Port 7 bit 6 Mode 0
   #define P77M0 0x80 //Port 7 bit 7 Mode 0

SFR(CMPCR1, 0xE6);              //0000,0000 Comparator Control Register 1
   #define CMPRES 0x01 //Comparator Result
   #define CMPOE  0x02 //Comparator Output Enable
   #define NIS    0x04 //Negative Input Source Selection
   #define PIS    0x08 //Positive Input Source Selection
   #define NIE    0x10 //Falling Edge Interrupt Enable
   #define PIE    0x20 //Rising Edge Interrupt Enable
   #define CMPIF  0x40 //Comparator Interrupt Flag
   #define CMPEN  0x80 //Comparator Enable

SFR(CMPCR2, 0xE7);              //0000,1001 Comparator Control Register 2
   #define LCDTY   0x3F //Digital Filter Control
   #define DISFLT  0x40 //Analog Filter Control
   #define INVCMPO 0x80 //Comparator Output Control

SFR(P6, 0xE8);                  //1111,1111 Port 6
   SBIT(P60,  0xE8, 0); //Port 6 Bit 0
   SBIT(P61,  0xE8, 1); //Port 6 Bit 1
   SBIT(P62,  0xE8, 2); //Port 6 Bit 2
   SBIT(P63,  0xE8, 3); //Port 6 Bit 3
   SBIT(P64,  0xE8, 4); //Port 6 Bit 4
   SBIT(P65,  0xE8, 5); //Port 6 Bit 5
   SBIT(P66,  0xE8, 6); //Port 6 Bit 6
   SBIT(P67,  0xE8, 7); //Port 6 Bit 7
   SBIT(P6_0,  0xE8, 0); //Port 6 Bit 0
   SBIT(P6_1,  0xE8, 1); //Port 6 Bit 1
   SBIT(P6_2,  0xE8, 2); //Port 6 Bit 2
   SBIT(P6_3,  0xE8, 3); //Port 6 Bit 3
   SBIT(P6_4,  0xE8, 4); //Port 6 Bit 4
   SBIT(P6_5,  0xE8, 5); //Port 6 Bit 5
   SBIT(P6_6,  0xE8, 6); //Port 6 Bit 6
   SBIT(P6_7,  0xE8, 7); //Port 6 Bit 7

SFR(CL, 0xE9);                  //0000,0000 PCA Counter Low Byte

SFR(CCAP0L, 0xEA);              //0000,0000 PCA Module 0 Capture/Compare Register Low Byte

SFR(CCAP1L, 0xEB);              //0000,0000 PCA Module 1 Capture/Compare Register Low Byte

SFR(B, 0xF0);                   //0000,0000 B Register
   SBIT(B0, 0xF0, 0); //B Bit 0
   SBIT(B1, 0xF0, 1); //B Bit 1
   SBIT(B2, 0xF0, 2); //B Bit 2
   SBIT(B3, 0xF0, 3); //B Bit 3
   SBIT(B4, 0xF0, 4); //B Bit 4
   SBIT(B5, 0xF0, 5); //B Bit 5
   SBIT(B6, 0xF0, 6); //B Bit 6
   SBIT(B7, 0xF0, 7); //B Bit 7
   SBIT(B_0, 0xF0, 0); //B Bit 0
   SBIT(B_1, 0xF0, 1); //B Bit 1
   SBIT(B_2, 0xF0, 2); //B Bit 2
   SBIT(B_3, 0xF0, 3); //B Bit 3
   SBIT(B_4, 0xF0, 4); //B Bit 4
   SBIT(B_5, 0xF0, 5); //B Bit 5
   SBIT(B_6, 0xF0, 6); //B Bit 6
   SBIT(B_7, 0xF0, 7); //B Bit 7

SFR(PWMCFG, 0xF1);              //0000,0000 PCA Module 0 PWM Register
   #define C2INI  0x01 //PWM 2 Initial Output Level
   #define C3INI  0x02 //PWM 3 Initial Output Level
   #define C4INI  0x04 //PWM 4 Initial Output Level
   #define C5INI  0x08 //PWM 5 Initial Output Level
   #define C6INI  0x10 //PWM 6 Initial Output Level
   #define C7INI  0x20 //PWM 7 Initial Output Level
   #define CBTADC 0x40 //PWM Trigger ADC

SFR(PCA_PWM0, 0xF2);            //00xx,xx00|xxxx,xx00 Programmable Counter Array Module 0 PWM Register
   #define EPC0L   0x01 //MSB of comparison vaule in PWM mode 
   #define EPC0H   0x02 //MSB of reload vaule in PWM mode
   #define XCCAP0L 0x0C //9th & 10th bit of comparison value in PWM mode
   #define XCCAP0H 0x30 //9th & 10th bit of reload value in PWM mode
   #define EBS0_0  0x40 //Number of PCAn PWM Bits Control 0
   #define EBS0_1  0x80 //Number of PCAn PWM Bits Control 1
   #define EBS0    0xC0 //Number of PCAn PWM Bits Control

SFR(PCA_PWM1, 0xF3);            //00xx,xx00|xxxx,xx00 Programmable Counter Array Module 1 PWM Register
   #define EPC1L   0x01 //MSB of comparison vaule in PWM mode 
   #define EPC1H   0x02 //MSB of reload vaule in PWM mode
   #define XCCAP1L 0x0C //9th & 10th bit of comparison value in PWM mode
   #define XCCAP1H 0x30 //9th & 10th bit of reload value in PWM mode
   #define EBS1_0  0x40 //Number of PCAn PWM Bits Control 0
   #define EBS1_1  0x80 //Number of PCAn PWM Bits Control 1
   #define EBS1    0xC0 //Number of PCAn PWM Bits Control

SFR(PWMCR, 0xF5);               //0000,0000 PWM Control Register
   #define ENC2O 0x01 //Enable PWM 2 Output
   #define ENC3O 0x02 //Enable PWM 3 Output
   #define ENC4O 0x04 //Enable PWM 4 Output
   #define ENC5O 0x08 //Enable PWM 5 Output
   #define ENC6O 0x10 //Enable PWM 6 Output
   #define ENC7O 0x20 //Enable PWM 7 Output
   #define ECBI  0x40 //Enable PWM Interrupt
   #define ENPWM 0x80 //Enable PWM

SFR(PWMIF, 0xF6);               //x000,0000|0000,0000 Interrupt Flag Register
   #define C2IF 0x01 //PWM 2 Interrupt Flag
   #define C3IF 0x02 //PWM 3 Interrupt Flag
   #define C4IF 0x04 //PWM 4 Interrupt Flag
   #define C5IF 0x08 //PWM 5 Interrupt Flag
   #define C6IF 0x10 //PWM 6 Interrupt Flag
   #define C7IF 0x20 //PWM 7 Interrupt Flag
   #define CBIF 0x40 //PWM Interrupt Flag

SFR(PWMFDCR, 0xF7);             //xx00,0000|0000,0000 PWM Fault Detect Control Register
   #define FDIF    0x01 //Fault Detect Interrupt Flag
   #define FDIO    0x02 //Fault Detect Input Output
   #define FDCMP   0x04 //Fault Detect Comparator
   #define EFDI    0x08 //Enable Fault Detect Interrupt
   #define FLTFLIO 0x10 //Faut Flag Input Output
   #define ENFD    0x20 //Enable Fault Detection

SFR(P7, 0xF8);                  //1111,1111 Port 7
   SBIT(P70, 0xF8, 0); //Port 7 Bit 0
   SBIT(P71, 0xF8, 1); //Port 7 Bit 1
   SBIT(P72, 0xF8, 2); //Port 7 Bit 2
   SBIT(P73, 0xF8, 3); //Port 7 Bit 3
   SBIT(P74, 0xF8, 4); //Port 7 Bit 4
   SBIT(P75, 0xF8, 5); //Port 7 Bit 5
   SBIT(P76, 0xF8, 6); //Port 7 Bit 6
   SBIT(P77, 0xF8, 7); //Port 7 Bit 7
   SBIT(P7_0, 0xF8, 0); //Port 7 Bit 0
   SBIT(P7_1, 0xF8, 1); //Port 7 Bit 1
   SBIT(P7_2, 0xF8, 2); //Port 7 Bit 2
   SBIT(P7_3, 0xF8, 3); //Port 7 Bit 3
   SBIT(P7_4, 0xF8, 4); //Port 7 Bit 4
   SBIT(P7_5, 0xF8, 5); //Port 7 Bit 5
   SBIT(P7_6, 0xF8, 6); //Port 7 Bit 6
   SBIT(P7_7, 0xF8, 7); //Port 7 Bit 7

SFR(CH, 0xF9);                  //0000,0000 PCA Counter High Byte

SFR(CCAP0H, 0xFA);              //0000,0000 PCA Module 0 Capture/Compare Register High Byte

SFR(CCAP1H, 0xFB);              //0000,0000 PCA Module 1 Capture/Compare Register High Byte

// The following special function registers are in the extended RAM area.
// You need to set bit7 of P_SW2 EAXFR to 1 to read and write them normally.
#define PWM2T1      (*(unsigned int  volatile xdata *)0xff00) //          PWM 2 Timer 1 Word
#define PWM2T1H     (*(unsigned char volatile xdata *)0xff00) //x000,0000 PWM 2 Timer 1 High Byte
#define PWM2T1L     (*(unsigned char volatile xdata *)0xff01) //0000,0000 PWM 2 Timer 1 Low Byte
#define PWM2T2      (*(unsigned int  volatile xdata *)0xff02) //          PWM 2 Timer 2 Word
#define PWM2T2H     (*(unsigned char volatile xdata *)0xff02) //x000,0000 PWM 2 Timer 2 High Byte
#define PWM2T2L     (*(unsigned char volatile xdata *)0xff03) //0000,0000 PWM 2 Timer 2 Low Byte
#define PWM2CR      (*(unsigned char volatile xdata *)0xff04) //          PWM 2 Control register
   #define EC2T1SI 0x01 //Trigger Point 1 Interrupt Enable
   #define EC2T2SI 0x02 //Trigger Point 2 Interrupt Enable
   #define EPWM2I  0x04 //Interrupt Enable
   #define PWM2_PS 0x08 //Output Pin Selection
#define PWM3T1      (*(unsigned int  volatile xdata *)0xff10) //          PWM 3 Timer 1 Word
#define PWM3T1H     (*(unsigned char volatile xdata *)0xff10) //x000,0000 PWM 3 Timer 1 High Byte
#define PWM3T1L     (*(unsigned char volatile xdata *)0xff11) //0000,0000 PWM 3 Timer 1 Low Byte
#define PWM3T2      (*(unsigned int  volatile xdata *)0xff12) //          PWM 3 Timer 2 Word
#define PWM3T2H     (*(unsigned char volatile xdata *)0xff12) //x000,0000 PWM 3 Timer 2 High Byte
#define PWM3T2L     (*(unsigned char volatile xdata *)0xff13) //0000,0000 PWM 3 Timer 2 Low Byte
#define PWM3CR      (*(unsigned char volatile xdata *)0xff14) //          PWM 3 Control register
   #define EC3T1SI 0x01 //Trigger Point 1 Interrupt Enable
   #define EC3T2SI 0x02 //Trigger Point 2 Interrupt Enable
   #define EPWM3I  0x04 //Interrupt Enable
   #define PWM3_PS 0x08 //Output Pin Selection
#define PWM4T1      (*(unsigned int  volatile xdata *)0xff20) //          PWM 4 Timer 1 Word
#define PWM4T1H     (*(unsigned char volatile xdata *)0xff20) //x000,0000 PWM 4 Timer 1 High Byte
#define PWM4T1L     (*(unsigned char volatile xdata *)0xff21) //0000,0000 PWM 4 Timer 1 Low Byte
#define PWM4T2      (*(unsigned int  volatile xdata *)0xff22) //          PWM 4 Timer 2 Word
#define PWM4T2H     (*(unsigned char volatile xdata *)0xff22) //x000,0000 PWM 4 Timer 2 High Byte
#define PWM4T2L     (*(unsigned char volatile xdata *)0xff23) //0000,0000 PWM 4 Timer 2 Low Byte
#define PWM4CR      (*(unsigned char volatile xdata *)0xff24) //          PWM 4 Control register
   #define EC4T1SI 0x01 //Trigger Point 1 Interrupt Enable
   #define EC4T2SI 0x02 //Trigger Point 2 Interrupt Enable
   #define EPWM4I  0x04 //Interrupt Enable
   #define PWM4_PS 0x08 //Output Pin Selection
#define PWM5T1      (*(unsigned int  volatile xdata *)0xff30) //          PWM 5 Timer 1 Word
#define PWM5T1H     (*(unsigned char volatile xdata *)0xff30) //x000,0000 PWM 5 Timer 1 High Byte
#define PWM5T1L     (*(unsigned char volatile xdata *)0xff31) //0000,0000 PWM 5 Timer 1 Low Byte
#define PWM5T2      (*(unsigned int  volatile xdata *)0xff32) //          PWM 5 Timer 2 Word
#define PWM5T2H     (*(unsigned char volatile xdata *)0xff32) //x000,0000 PWM 5 Timer 2 High Byte
#define PWM5T2L     (*(unsigned char volatile xdata *)0xff33) //0000,0000 PWM 5 Timer 2 Low Byte
#define PWM5CR      (*(unsigned char volatile xdata *)0xff34) //          PWM 5 Control register
   #define EC5T1SI 0x01 //Trigger Point 1 Interrupt Enable
   #define EC5T2SI 0x02 //Trigger Point 2 Interrupt Enable
   #define EPWM5I  0x04 //Interrupt Enable
   #define PWM5_PS 0x08 //Output Pin Selection
#define PWM6T1      (*(unsigned int  volatile xdata *)0xff40) //          PWM 6 Timer 1 Word
#define PWM6T1H     (*(unsigned char volatile xdata *)0xff40) //x000,0000 PWM 6 Timer 1 High Byte
#define PWM6T1L     (*(unsigned char volatile xdata *)0xff41) //0000,0000 PWM 6 Timer 1 Low Byte
#define PWM6T2      (*(unsigned int  volatile xdata *)0xff42) //          PWM 6 Timer 2 Word
#define PWM6T2H     (*(unsigned char volatile xdata *)0xff42) //x000,0000 PWM 6 Timer 2 High Byte
#define PWM6T2L     (*(unsigned char volatile xdata *)0xff43) //0000,0000 PWM 6 Timer 2 Low Byte
#define PWM6CR      (*(unsigned char volatile xdata *)0xff44) //          PWM 6 Control register
   #define EC6T1SI 0x01 //Trigger Point 1 Interrupt Enable
   #define EC6T2SI 0x02 //Trigger Point 2 Interrupt Enable
   #define EPWM6I  0x04 //Interrupt Enable
   #define PWM6_PS 0x08 //Output Pin Selection
#define PWM7T1      (*(unsigned int  volatile xdata *)0xff50) //          PWM 7 Timer 1 Word
#define PWM7T1H     (*(unsigned char volatile xdata *)0xff50) //x000,0000 PWM 7 Timer 1 High Byte
#define PWM7T1L     (*(unsigned char volatile xdata *)0xff51) //0000,0000 PWM 7 Timer 1 Low Byte
#define PWM7T2      (*(unsigned int  volatile xdata *)0xff52) //          PWM 7 Timer 2 Word
#define PWM7T2H     (*(unsigned char volatile xdata *)0xff52) //x000,0000 PWM 7 Timer 2 High Byte
#define PWM7T2L     (*(unsigned char volatile xdata *)0xff53) //0000,0000 PWM 7 Timer 2 Low Byte
#define PWM7CR      (*(unsigned char volatile xdata *)0xff54) //          PWM 7 Control register
   #define EC7T1SI 0x01 //Trigger Point 1 Interrupt Enable
   #define EC7T2SI 0x02 //Trigger Point 2 Interrupt Enable
   #define EPWM7I  0x04 //Interrupt Enable
   #define PWM7_PS 0x08 //Output Pin Selection
#define PWMC        (*(unsigned int  volatile xdata *)0xfff0) //          PWM Counter Word
#define PWMCH       (*(unsigned char volatile xdata *)0xfff0) //x000,0000 PWM Counter High Byte
#define PWMCL       (*(unsigned char volatile xdata *)0xfff1) //0000,0000 PWM Counter Low Byte
#define PWMCKS      (*(unsigned char volatile xdata *)0xfff2) //xxx0,0000 PWM Clock Selection
   #define PWM_PS 0x0F //PWM System Clock Prescaler
   #define SELT2  0x10 //PWM Clock source selection

//Interrupt_Address = ( Interrupt_Number * 8 ) + 3
//Vectors are named after their corresponding IE, IP or IR register bit so
//that we don't have to invent names and can be more consistent across MCUs.
   #define X0_VECTOR  0  // 0x03 External Interrupt 0
   #define T0_VECTOR  1  // 0x0B Timer 0
   #define X1_VECTOR  2  // 0x13 External Interrupt 1
   #define T1_VECTOR  3  // 0x1B Timer 1
   #define S_VECTOR   4  // 0x23 Serial Port 1
   #define ADC_VECTOR 5  // 0x2B Analog to Digital Converter
   #define LVD_VECTOR 6  // 0x33 Low Voltage Detect
   #define PCA_VECTOR 7  // 0x3B Programmable Counter Array (CCP)
   #define S2_VECTOR  8  // 0x43 Serial Port 2
   #define SPI_VECTOR 9  // 0x4B Serial Peripheral Interface
   #define X2_VECTOR  10 // 0x53 External Interrupt 2
   #define X3_VECTOR  11 // 0x5B External Interrupt 3
   #define T2_VECTOR  12 // 0x63 Timer 2
   //       -         13    0x6B        -
   //       -         14    0x73 System Reserved
   //       -         15    0x7B System Reserved
   #define X4_VECTOR  16 // 0x83 External Interrupt 4
   #define S3_VECTOR  17 // 0x8B Serial Port 3
   #define S4_VECTOR  18 // 0x93 Serial Port 4
   #define T3_VECTOR  19 // 0x9B Timer 3
   #define T4_VECTOR  20 // 0xA3 Timer 4
   #define CMP_VECTOR 21 // 0xAB Comparator
   #define PWM_VECTOR 22 // 0xB3 Pulse Width Modulator
   #define PFD_VECTOR 23 // 0xBB PWM Fault Detect

#endif
