// PIO compatible header file STC15-F-L.h 20210829.
// For use only with series STC15F10xx STC15F20xx STC15L10xx
// STC15L20xx IAP15F10xx IAP15F20xx IAP15L10xx IAP15L20xx
// IRC15F20xx IRC15F10xx IRC15L10xx IRC15L20xx MCUs.
// This header is for first generation simple STC15 MCUs
// and has been checked against the corresponding datasheet.

#ifndef STC15_F_L_H
#define STC15_F_L_H
#include <compiler.h>

// Special Function Register | POR Reset Value | Description

SFR(P0, 0x80);                  //1111,1111 Port 0
   SBIT(RST,     0x80, 0); //Reset
   SBIT(SYSclkO, 0x80, 0); //System Clock Out
   SBIT(P00, 0x80, 0); //Port 0 Bit 0
   SBIT(P01, 0x80, 1); //Port 0 Bit 1
   SBIT(P0_0, 0x80, 0); //Port 0 Bit 0
   SBIT(P0_1, 0x80, 1); //Port 0 Bit 1

SFR(SP, 0x81);                  //0000,0111 Stack Pointer

SFR(DPTR, 0x82);                //0000,0000 Data Pointer Word
SFR(DPL, 0x82);                 //0000,0000 Data Pointer Low Byte

SFR(DPH, 0x83);                 //0000,0000 Data Pointer High Byte

SFR(PCON, 0x87);                //xx11,0000 Power Control Register
   #define IDL   0x01 //Idle Mode Control
   #define PD    0x02 //Power Down Mode Control
   #define GF0   0x04 //User Defined Gereral Purpose Flag 0
   #define GF1   0x08 //User Defined General Purpose Flag 1
   #define POF   0x10 //Power On Flag
   #define LVDF  0x20 //Low Voltage Detect Flag

SFR(TCON, 0x88);                //0000,0000 T0/T1 Control Register
   SBIT(IT0, 0x88, 0); //Interrupt 0 Type
   SBIT(IE0, 0x88, 1); //Interrupt 0 Edge
   SBIT(IT1, 0x88, 2); //Interrupt 1 Type
   SBIT(IE1, 0x88, 3); //Interrupt 1 Edge
   SBIT(TR0, 0x88, 4); //Timer 0 Run
   SBIT(TF0, 0x88, 5); //Timer 0 Flag
   SBIT(TR1, 0x88, 6); //Timer 1 Run
   SBIT(TF1, 0x88, 7); //Timer 1 Flag

SFR(TMOD, 0x89);                //0000,0000 T0/T1 Mode Register
   #define T0_M0   0x01 //Timer 0 Mode 0
   #define T0_M1   0x02 //Timer 0 Mode 1
   #define T0_M    0x03 //Timer 0 Mode
   #define T0_CT   0x04 //Timer 0 Counter Timer
   #define T0_GATE 0x08 //Timer 0 Gate
   #define T1_M0   0x10 //Timer 1 Mode 0
   #define T1_M1   0x20 //Timer 1 Mode 1
   #define T1_M    0x30 //Timer 1 Mode
   #define T1_CT   0x40 //Timer 1 Counter Timer
   #define T1_GATE 0x80 //Timer 1 Gate
   #define M00   0x01 //Mode 0 Timer 0
   #define M10   0x02 //Mode 1 Timer 0
   #define M0    0x03 //Timer 0 Mode
   #define CT0   0x04 //Counter Timer 0
   #define GATE0 0x08 //Gate 0
   #define M01   0x10 //Mode 1 Timer 1
   #define M11   0x20 //Mode 1 Timer 1
   #define M1    0x30 //Timer 1 Mode
   #define CT1   0x40 //Counter Timer 1
   #define GATE1 0x80 //Gate 1

SFR(TL0, 0x8A);                 //0000,0000 Timer 0 Low Byte
SFR(RL_TL0, 0x8A);              //0000,0000 Reload Timer 0 Low Byte

SFR(TL1, 0x8B);                 //0000,0000 Timer 1 Low Byte
SFR(RL_TL1, 0x8B);              //0000,0000 Reload Timer 1 Low Byte

SFR(TH0, 0x8C);                 //0000,0000 Timer 0 High Byte
SFR(RL_TH0, 0x8C);              //0000,0000 Reload Timer 0 High Byte

SFR(TH1, 0x8D);                 //0000,0000 Timer 1 High Byte
SFR(RL_TH1, 0x8D);              //0000,0000 Reload Timer 1 High Byte

SFR(AUXR, 0x8E);                //00xx,xxxx Auxiliary Register
   #define T1x12     0x40 //Timer 1 Clock x12 Prescaler Bypass
   #define T0x12     0x80 //Timer 0 Clock x12 Prescaler Bypass

SFR(INT_CLKO, 0x8F);            //x000,xx00 Interrupt and Clock Output Control Register
SFR(AUXR2, 0x8F);               //x000,xx00 Auxiliary Register 2
   #define T0CLKO  0x01 //Timer 0 Clock Output Control
   #define T1CLKO  0x02 //Timer 1 Clock Output Control
   #define EX2     0x10 //External Interrupt 3 Enable
   #define EX3     0x20 //External Interrupt 2 Enable
   #define EX4     0x40 //External Interrupt 4 Enable

SFR(P1, 0x90);                  //1111,1111 Port 1
   SBIT(ACH0, 0x90, 0); //ADC Channel 0
   SBIT(ACH1, 0x90, 1); //ADC Channel 1
   SBIT(ACH2, 0x90, 2); //ADC Channel 2
   SBIT(ACH3, 0x90, 3); //ADC Channel 3
   SBIT(ACH4, 0x90, 4); //ADC Channel 4
   SBIT(ACH5, 0x90, 5); //ADC Channel 5
   SBIT(ACH6, 0x90, 6); //ADC Channel 6
   SBIT(ACH7, 0x90, 7); //ADC Channel 7
   SBIT(ADC0, 0x90, 0); //AtoD Channel 0
   SBIT(ADC1, 0x90, 1); //AtoD Channel 1
   SBIT(ADC2, 0x90, 2); //AtoD Channel 2
   SBIT(ADC3, 0x90, 3); //AtoD Channel 3
   SBIT(ADC4, 0x90, 4); //AtoD Channel 4
   SBIT(ADC5, 0x90, 5); //AtoD Channel 5
   SBIT(ADC6, 0x90, 6); //AtoD Channel 6
   SBIT(ADC7, 0x90, 7); //AtoD Channel 7
   SBIT(AIN0, 0x90, 0); //Analog Input 0
   SBIT(AIN1, 0x90, 1); //Analog Input 1
   SBIT(AIN2, 0x90, 2); //Analog Input 2
   SBIT(AIN3, 0x90, 3); //Analog Input 3
   SBIT(AIN4, 0x90, 4); //Analog Input 4
   SBIT(AIN5, 0x90, 5); //Analog Input 5
   SBIT(AIN6, 0x90, 6); //Analog Input 6
   SBIT(AIN7, 0x90, 7); //Analog Input 7
   SBIT(P10, 0x90, 0); //Port 1 Bit 0
   SBIT(P11, 0x90, 1); //Port 1 Bit 1
   SBIT(P12, 0x90, 2); //Port 1 Bit 2
   SBIT(P13, 0x90, 3); //Port 1 Bit 3
   SBIT(P14, 0x90, 4); //Port 1 Bit 4
   SBIT(P15, 0x90, 5); //Port 1 Bit 5
   SBIT(P16, 0x90, 6); //Port 1 Bit 6
   SBIT(P17, 0x90, 7); //Port 1 Bit 7
   SBIT(P1_0, 0x90, 0); //Port 1 Bit 0
   SBIT(P1_1, 0x90, 1); //Port 1 Bit 1
   SBIT(P1_2, 0x90, 2); //Port 1 Bit 2
   SBIT(P1_3, 0x90, 3); //Port 1 Bit 3
   SBIT(P1_4, 0x90, 4); //Port 1 Bit 4
   SBIT(P1_5, 0x90, 5); //Port 1 Bit 5
   SBIT(P1_6, 0x90, 6); //Port 1 Bit 6
   SBIT(P1_7, 0x90, 7); //Port 1 Bit 7

SFR(P1M1, 0x91);                //0000,0000 Port 1 Mode Register 1
   #define P10M1 0x01 //Port 1 bit 0 Mode 1
   #define P11M1 0x02 //Port 1 bit 1 Mode 1
   #define P12M1 0x04 //Port 1 bit 2 Mode 1
   #define P13M1 0x08 //Port 1 bit 3 Mode 1
   #define P14M1 0x10 //Port 1 bit 4 Mode 1
   #define P15M1 0x20 //Port 1 bit 5 Mode 1
   #define P16M1 0x40 //Port 1 bit 6 Mode 1
   #define P17M1 0x80 //Port 1 bit 7 Mode 1

SFR(P1M0, 0x92);                //0000,0000 Port 1 Mode Register 0
   #define P10M0 0x01 //Port 1 bit 0 Mode 0
   #define P11M0 0x02 //Port 1 bit 1 Mode 0
   #define P12M0 0x04 //Port 1 bit 2 Mode 0
   #define P13M0 0x08 //Port 1 bit 3 Mode 0
   #define P14M0 0x10 //Port 1 bit 4 Mode 0
   #define P15M0 0x20 //Port 1 bit 5 Mode 0
   #define P16M0 0x40 //Port 1 bit 6 Mode 0
   #define P17M0 0x80 //Port 1 bit 7 Mode 0

SFR(P0M1, 0x93);                //0000,0000 Port 0 Mode Register 1
   #define P00M1 0x01 //Port 0 bit 0 Mode 1
   #define P01M1 0x02 //Port 0 bit 1 Mode 1

SFR(P0M0, 0x94);                //0000,0000 Port 0 Mode Register 0
   #define P00M0 0x01 //Port 0 bit 0 Mode 0
   #define P01M0 0x02 //Port 0 bit 1 Mode 0

SFR(P2M1, 0x95);                //0000,0000 Port 2 Mode Register 1
   #define P20M1 0x01 //Port 2 bit 0 Mode 1
   #define P21M1 0x02 //Port 2 bit 1 Mode 1
   #define P22M1 0x04 //Port 2 bit 2 Mode 1
   #define P23M1 0x08 //Port 2 bit 3 Mode 1
   #define P24M1 0x10 //Port 2 bit 4 Mode 1
   #define P25M1 0x20 //Port 2 bit 5 Mode 1
   #define P26M1 0x40 //Port 2 bit 6 Mode 1
   #define P27M1 0x80 //Port 2 bit 7 Mode 1

SFR(P2M0, 0x96);                //0000,0000 Port 2 Mode Register 0
   #define P20M0 0x01 //Port 2 bit 0 Mode 0
   #define P21M0 0x02 //Port 2 bit 1 Mode 0
   #define P22M0 0x04 //Port 2 bit 2 Mode 0
   #define P23M0 0x08 //Port 2 bit 3 Mode 0
   #define P24M0 0x10 //Port 2 bit 4 Mode 0
   #define P25M0 0x20 //Port 2 bit 5 Mode 0
   #define P26M0 0x40 //Port 2 bit 6 Mode 0
   #define P27M0 0x80 //Port 2 bit 7 Mode 0

SFR(CLK_DIV, 0x97);             //xxxx,x000 Clock Division Control Register
SFR(PCON2, 0x97);               //xxxx,x000 Power Control Register 2
   #define CLKS0 0x01 //Clock Select 0
   #define CLKS1 0x02 //Clock Select 1
   #define CLKS2 0x04 //Clock Select 2
   #define CLKS  0x07 //Clock Select

SFR(P1ASF, 0x9D);               //0000,0000 Port 1 Analog Function Configuration Register
   #define P10ASF 0x01 //Port 1 bit 0 Analog Special Function
   #define P11ASF 0x02 //Port 1 bit 1 Analog Special Function
   #define P12ASF 0x04 //Port 1 bit 2 Analog Special Function
   #define P13ASF 0x08 //Port 1 bit 3 Analog Special Function
   #define P14ASF 0x10 //Port 1 bit 4 Analog Special Function
   #define P15ASF 0x20 //Port 1 bit 5 Analog Special Function
   #define P16ASF 0x40 //Port 1 bit 6 Analog Special Function
   #define P17ASF 0x80 //Port 1 bit 7 Analog Special Function

SFR(P2, 0xA0);                  //1111,1111 Port 2
   SBIT(RSTOUT_LOW, 0xA0, 0); //Reset Out Low
   SBIT(P20, 0xA0, 0); //Port 2 Bit 0
   SBIT(P21, 0xA0, 1); //Port 2 Bit 1
   SBIT(P22, 0xA0, 2); //Port 2 Bit 2
   SBIT(P23, 0xA0, 3); //Port 2 Bit 3
   SBIT(P24, 0xA0, 4); //Port 2 Bit 4
   SBIT(P25, 0xA0, 5); //Port 2 Bit 5
   SBIT(P26, 0xA0, 6); //Port 2 Bit 6
   SBIT(P27, 0xA0, 7); //Port 2 Bit 7
   SBIT(P2_0, 0xA0, 0); //Port 2 Bit 0
   SBIT(P2_1, 0xA0, 1); //Port 2 Bit 1
   SBIT(P2_2, 0xA0, 2); //Port 2 Bit 2
   SBIT(P2_3, 0xA0, 3); //Port 2 Bit 3
   SBIT(P2_4, 0xA0, 4); //Port 2 Bit 4
   SBIT(P2_5, 0xA0, 5); //Port 2 Bit 5
   SBIT(P2_6, 0xA0, 6); //Port 2 Bit 6
   SBIT(P2_7, 0xA0, 7); //Port 2 Bit 7

SFR(IE, 0xA8);                  //000x,0000 Interrupt Control Register
   SBIT(EX0,  0xA8, 0); //Enable External 0
   SBIT(ET0,  0xA8, 1); //Enable Timer 0
   SBIT(EX1,  0xA8, 2); //Enable External 1
   SBIT(ET1,  0xA8, 3); //Enable Timer 1
   SBIT(EADC, 0xA8, 5); //Enable ADC
   SBIT(ELVD, 0xA8, 6); //Enable Low Voltage Detect
   SBIT(EA,   0xA8, 7); //Enable All

SFR(WKTCL, 0xAA);               //0111,1111|1111,1111 Power Down Wakeup Timer Control Low Byte
SFR(WKTCL_CNT, 0xAA);           //0111,1111|1111,1111 Power Down Wakeup Timer Control Count

SFR(WKTCH, 0xAB);               //0111,1111 Power Down Wakeup Timer Control High Byte
   #define WKTEN 0x80 //Power Down Wakeup Timer Enable
SFR(WKTCH_CNT, 0xAB);           //0111,1111|x111,1111 Power Down Wakeup Timer Control Count


SFR(P3, 0xB0);                  //1111,1111 Port 3
   SBIT(INT4,    0xB0, 0); //Interrupt 4
   SBIT(INT0,    0xB0, 2); //Interrupt 0
   SBIT(INT1,    0xB0, 3); //Interrupt 1
   SBIT(T0,      0xB0, 4); //Timer 0
   SBIT(CLKOUT1, 0xB0, 4); //Clock Out 1
   SBIT(T1,      0xB0, 5); //Timer 1
   SBIT(CLKOUT2, 0xB0, 5); //Clock Out 0
   SBIT(INT2,    0xB0, 6); //Interrupt 2
   SBIT(INT3,    0xB0, 7); //Interrupt 3
   SBIT(P30, 0xB0, 0); //Port 3 Bit 0
   SBIT(P31, 0xB0, 1); //Port 3 Bit 1
   SBIT(P32, 0xB0, 2); //Port 3 Bit 2
   SBIT(P33, 0xB0, 3); //Port 3 Bit 3
   SBIT(P34, 0xB0, 4); //Port 3 Bit 4
   SBIT(P35, 0xB0, 5); //Port 3 Bit 5
   SBIT(P36, 0xB0, 6); //Port 3 Bit 6
   SBIT(P37, 0xB0, 7); //Port 3 Bit 7
   SBIT(P3_0, 0xB0, 0); //Port 3 Bit 0
   SBIT(P3_1, 0xB0, 1); //Port 3 Bit 1
   SBIT(P3_2, 0xB0, 2); //Port 3 Bit 2
   SBIT(P3_3, 0xB0, 3); //Port 3 Bit 3
   SBIT(P3_4, 0xB0, 4); //Port 3 Bit 4
   SBIT(P3_5, 0xB0, 5); //Port 3 Bit 5
   SBIT(P3_6, 0xB0, 6); //Port 3 Bit 6
   SBIT(P3_7, 0xB0, 7); //Port 3 Bit 7

SFR(P3M1, 0xB1);                //0000,0000 Port 3 Mode Register 1
   #define P30M1 0x01 //Port 3 bit 0 Mode 1
   #define P31M1 0x02 //Port 3 bit 1 Mode 1
   #define P32M1 0x04 //Port 3 bit 2 Mode 1
   #define P33M1 0x08 //Port 3 bit 3 Mode 1
   #define P34M1 0x10 //Port 3 bit 4 Mode 1
   #define P35M1 0x20 //Port 3 bit 5 Mode 1
   #define P36M1 0x40 //Port 3 bit 6 Mode 1
   #define P37M1 0x80 //Port 3 bit 7 Mode 1

SFR(P3M0, 0xB2);                //0000,0000 Port 3 Mode Register 0
   #define P30M0 0x01 //Port 3 bit 0 Mode 0
   #define P31M0 0x02 //Port 3 bit 1 Mode 0
   #define P32M0 0x04 //Port 3 bit 2 Mode 0
   #define P33M0 0x08 //Port 3 bit 3 Mode 0
   #define P34M0 0x10 //Port 3 bit 4 Mode 0
   #define P35M0 0x20 //Port 3 bit 5 Mode 0
   #define P36M0 0x40 //Port 3 bit 6 Mode 0
   #define P37M0 0x80 //Port 3 bit 7 Mode 0

SFR(IP, 0xB8);                  //x00x,0000|x0x0,0000 Interrupt Priority Register
   SBIT(PX0,  0xB8, 0); //Priority External 0
   SBIT(PT0,  0xB8, 1); //Priority Timer 0
   SBIT(PX1,  0xB8, 2); //Priority External 1
   SBIT(PT1,  0xB8, 3); //Priority Timer 1
   SBIT(PADC, 0xB8, 5); //Priority ADC
   SBIT(PLVD, 0xB8, 6); //Priority Low Voltage Detect

SFR(IRC_CLKO, 0xBB);            //0xxx,0xxx Internal RC Clock Output Control Register
   #define DIVIRCO 0x08 //Divide Internal Resistor Capacitor Clock Ouptur
   #define EN_IRCO 0x80 //Enable Internal Resistor Capacitor Clock Output

SFR(ADC_CONTR, 0xBC);           //0000,0000 ADC Conversion Control Register
   #define CHS0      0x01 //Channel Select 0
   #define CHS1      0x02 //Channel Select 1
   #define CHS2      0x04 //Channel Select 2
   #define ADC_CHS   0x0F //ADC Analog Channel Select
   #define ADC_START 0x08 //Analog to Digital Converter Start
   #define ADC_FLAG  0x10 //Analog to Digital Converter Flag
   #define SPEED0    0x20 //Speed 0
   #define SPEED1    0x40 //Speed 1
   #define ADC_POWER 0x80 //Analog to Digital Converter Power

SFR(ADC_RES, 0xBD);             //0000,0000 ADC Conversion Result High 8 Bits

SFR(ADC_RESL, 0xBE);            //0000,0000 ADC Conversion Result Low 2 Bits

SFR(WDT_CONTR, 0xC1);           //0x00,0000 Watchdog Control Register
   #define PS0      0x01 //Watchdog Timer Prescaler 0
   #define PS1      0x02 //Watchdog Timer Prescaler 1
   #define PS2      0x04 //Watchdog Timer Prescaler 2
   #define WDTPS0   0x01 //Watchdog Timer Prescaler 0
   #define WDTPS1   0x02 //Watchdog Timer Prescaler 1
   #define WDTPS2   0x04 //Watchdog Timer Prescaler 2
   #define WDT_PS   0x07 //Watchdog Timer Prescaler
   #define IDL_WDT  0x08 //Watchdog Timer Idle Mode Behavior
   #define CLR_WDT  0x10 //Clear Watchdog Timer
   #define EN_WDT   0x20 //Enable Watchdog Timer
   #define WDT_FLAG 0x80 //Watchdog Timer Overflow Flag

SFR(IAP_DATA, 0xC2);            //1111,1111 In Application Programming Data
SFR(ISP_DATA, 0xC2);            //1111,1111 In System Programming Data

SFR(IAP_ADDRH, 0xC3);           //0000,0000 In Application Programming Address High
SFR(ISP_ADDRH, 0xC3);           //0000,0000 In System Programming Address High

SFR(IAP_ADDRL, 0xC4);           //0000,0000 In Application Programming Address Low
SFR(ISP_ADDRL, 0xC4);           //0000,0000 In System Programming Address Low

SFR(IAP_CMD, 0xC5);             //xxxx,x000|xxxx,xx00 In Application Programming Command
SFR(ISP_CMD, 0xC5);             //xxxx,x000|xxxx,xx00 In System Programming Command
   #define MS0    0x01 //Mode Select 0
   #define MS1    0x02 //Mode Select 1
   #define IAPCMD 0x03 //In Application Programming Command
// Valid commands follow
#define IAP_IDL   0x00
#define IAP_READ  0x01
#define IAP_WRITE 0x02
#define IAP_ERASE 0x03
// End of valid commands

SFR(IAP_TRIG, 0xC6);            //xxxx,xxxx In Application Programming Trigger
SFR(ISP_TRIG, 0xC6);            //xxxx,xxxx In System Programming Trigger

SFR(IAP_CONTR, 0xC7);           //0000,0000 In Application Programming Control
SFR(ISP_CONTR, 0xC7);           //0000,00x0|0000,0000 In System Programming Control
   #define WT0      0x01 //Wait 0
   #define WT1      0x02 //Wait 1
   #define WT2      0x04 //Wait 2
   #define IAP_WT   0x07 //In Application Programming Wait
   #define CMD_FAIL 0x10 //Command Fail
   #define SWRST    0x20 //Software Reset Trigger
   #define SWBS     0x40 //Software Boot Selection
   #define IAPEN    0x80 //In Application Programming Enable

SFR(PSW, 0xD0);                 //0000,00x0 Program status word
   SBIT(P,   0xD0, 0); //Parity
// SBIT(F1,  0xD0, 1); //Flag 1
   SBIT(OV,  0xD0, 2); //Overflow
   SBIT(RS0, 0xD0, 3); //Register Select 0
   SBIT(RS1, 0xD0, 4); //Register Select 1
   SBIT(F0,  0xD0, 5); //Flag 0
   SBIT(AC,  0xD0, 6); //Auxiliary Carry
   SBIT(CY,  0xD0, 7); //Carry

SFR(ACC, 0xE0);                 //0000,0000 Accumulator
   SBIT(ACC0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC7, 0xE0, 7); //Accumulator Bit 7
   SBIT(ACC_0, 0xE0, 0); //Accumulator Bit 0
   SBIT(ACC_1, 0xE0, 1); //Accumulator Bit 1
   SBIT(ACC_2, 0xE0, 2); //Accumulator Bit 2
   SBIT(ACC_3, 0xE0, 3); //Accumulator Bit 3
   SBIT(ACC_4, 0xE0, 4); //Accumulator Bit 4
   SBIT(ACC_5, 0xE0, 5); //Accumulator Bit 5
   SBIT(ACC_6, 0xE0, 6); //Accumulator Bit 6
   SBIT(ACC_7, 0xE0, 7); //Accumulator Bit 7

SFR(B, 0xF0);                   //0000,0000 B Register
   SBIT(B0, 0xF0, 0); //B Bit 0
   SBIT(B1, 0xF0, 1); //B Bit 1
   SBIT(B2, 0xF0, 2); //B Bit 2
   SBIT(B3, 0xF0, 3); //B Bit 3
   SBIT(B4, 0xF0, 4); //B Bit 4
   SBIT(B5, 0xF0, 5); //B Bit 5
   SBIT(B6, 0xF0, 6); //B Bit 6
   SBIT(B7, 0xF0, 7); //B Bit 7
   SBIT(B_0, 0xF0, 0); //B Bit 0
   SBIT(B_1, 0xF0, 1); //B Bit 1
   SBIT(B_2, 0xF0, 2); //B Bit 2
   SBIT(B_3, 0xF0, 3); //B Bit 3
   SBIT(B_4, 0xF0, 4); //B Bit 4
   SBIT(B_5, 0xF0, 5); //B Bit 5
   SBIT(B_6, 0xF0, 6); //B Bit 6
   SBIT(B_7, 0xF0, 7); //B Bit 7

//Interrupt_Address = ( Interrupt_Number * 8 ) + 3
//Vectors are named after their corresponding IE, IP or IR register bit so
//that we don't have to invent names and can be more consistent across MCUs.
   #define X0_VECTOR  0  // 0x03 External Interrupt 0
   #define T0_VECTOR  1  // 0x0B Timer 0
   #define X1_VECTOR  2  // 0x13 External Interrupt 1
   #define T1_VECTOR  3  // 0x1B Timer 1
   //       -         4  // 0x23        -
   #define ADC_VECTOR 5  // 0x2B Analog to Digital Converter
   #define LVD_VECTOR 6  // 0x33 Low Voltage Detect
   //       -         7  // 0x3B        -
   //       -         8  // 0x43        -
   //       -         9  // 0x4B        -
   #define X2_VECTOR  10 // 0x53 External Interrupt 2
   #define X3_VECTOR  11 // 0x5B External Interrupt 3
   //       -         12 // 0x63        -
   //       -         13    0x6B        -
   //       -         14    0x73 System Reserved
   //       -         15    0x7B System Reserved
   #define X4_VECTOR  16 // 0x83 External Interrupt 4

#endif
